@@ -37,7 +37,7 @@ CONF = cfg.CONF
 LOG = logging.getLogger(__name__)
 
 
-class InterfaceController(object):
+class InterfaceController:
     ADD = 'add'
     DELETE = 'delete'
     SET = 'set'
@@ -106,10 +106,9 @@ class InterfaceController(object):
     def _dhclient_up(self, interface_name):
         cmd = ["/sbin/dhclient",
                "-lf",
-               "/var/lib/dhclient/dhclient-{}.leases".format(
-                   interface_name),
+               f"/var/lib/dhclient/dhclient-{interface_name}.leases",
                "-pf",
-               "/run/dhclient-{}.pid".format(interface_name),
+               f"/run/dhclient-{interface_name}.pid",
                interface_name]
         LOG.debug("Running '%s'", cmd)
         subprocess.check_output(cmd, stderr=subprocess.STDOUT)
@@ -118,10 +117,9 @@ class InterfaceController(object):
         cmd = ["/sbin/dhclient",
                "-r",
                "-lf",
-               "/var/lib/dhclient/dhclient-{}.leases".format(
-                   interface_name),
+               f"/var/lib/dhclient/dhclient-{interface_name}.leases",
                "-pf",
-               "/run/dhclient-{}.pid".format(interface_name),
+               f"/run/dhclient-{interface_name}.pid",
                interface_name]
         LOG.debug("Running '%s'", cmd)
         subprocess.check_output(cmd, stderr=subprocess.STDOUT)
@@ -134,8 +132,7 @@ class InterfaceController(object):
                            ('autoconf', 1)):
             cmd = ["/sbin/sysctl",
                    "-w",
-                   "net.ipv6.conf.{}.{}={}".format(interface_name,
-                                                   key, value)]
+                   f"net.ipv6.conf.{interface_name}.{key}={value}"]
             LOG.debug("Running '%s'", cmd)
             subprocess.check_output(cmd, stderr=subprocess.STDOUT)
 
@@ -144,8 +141,7 @@ class InterfaceController(object):
                            ('autoconf', 0)):
             cmd = ["/sbin/sysctl",
                    "-w",
-                   "net.ipv6.conf.{}.{}={}".format(interface_name,
-                                                   key, value)]
+                   f"net.ipv6.conf.{interface_name}.{key}={value}"]
             LOG.debug("Running '%s'", cmd)
             subprocess.check_output(cmd, stderr=subprocess.STDOUT)
 
@@ -176,47 +172,12 @@ class InterfaceController(object):
         ip_network = ipaddress.ip_network(address, strict=False)
         return ip_network.compressed
 
-    def _setup_nftables_chain(self, interface):
-        # TODO(johnsom) Move this to pyroute2 when the nftables library
-        #               improves.
-
-        # Create the nftable
-        cmd = [consts.NFT_CMD, consts.NFT_ADD, 'table', consts.NFT_FAMILY,
-               consts.NFT_VIP_TABLE]
-        try:
-            subprocess.check_output(cmd, stderr=subprocess.STDOUT)
-        except Exception as e:
-            if hasattr(e, 'output'):
-                LOG.error(e.output)
-            else:
-                LOG.error(e)
-            raise
-
-        # Create the chain with -310 priority to put it in front of the
-        # lvs-masquerade configured chain
-        cmd = [consts.NFT_CMD, consts.NFT_ADD, 'chain', consts.NFT_FAMILY,
-               consts.NFT_VIP_TABLE, consts.NFT_VIP_CHAIN,
-               '{', 'type', 'filter', 'hook', 'ingress', 'device',
-               interface.name, 'priority', consts.NFT_SRIOV_PRIORITY, ';',
-               'policy', 'drop', ';', '}']
-        try:
-            subprocess.check_output(cmd, stderr=subprocess.STDOUT)
-        except Exception as e:
-            if hasattr(e, 'output'):
-                LOG.error(e.output)
-            else:
-                LOG.error(e)
-            raise
-
-        nftable_utils.write_nftable_vip_rules_file(interface.name, [])
-
-        nftable_utils.load_nftables_file()
-
     def up(self, interface):
         LOG.info("Setting interface %s up", interface.name)
 
         if interface.is_sriov:
-            self._setup_nftables_chain(interface)
+            nftable_utils.write_nftable_rules_file(interface.name, [])
+            nftable_utils.load_nftables_file()
 
         with pyroute2.IPRoute() as ipr:
             idx = ipr.link_lookup(ifname=interface.name)[0]
@@ -305,8 +266,8 @@ class InterfaceController(object):
                 'RTA_DST',
                 '0.0.0.0' if family == socket.AF_INET else '::')  # nosec
 
-            key = ("{}/{}".format(self._normalize_ip_address(dst),
-                                  route.get('dst_len', 0)),
+            key = (f"{self._normalize_ip_address(dst)}/"
+                   f"{route.get('dst_len', 0)}",
                    self._normalize_ip_address(attrs.get('RTA_GATEWAY')),
                    self._normalize_ip_address(attrs.get('RTA_PREFSRC')),
                    attrs.get('RTA_TABLE'))
