@@ -13,18 +13,18 @@
 # under the License.
 
 import ipaddress
+import json
 import os
 import stat
 
 from oslo_config import cfg
-import simplejson
 
 from octavia.common import constants as consts
 
 CONF = cfg.CONF
 
 
-class InterfaceFile(object):
+class InterfaceFile:
     def __init__(self, name, if_type, mtu=None, addresses=None,
                  routes=None, rules=None, scripts=None, is_sriov=False):
         self.name = name
@@ -45,11 +45,11 @@ class InterfaceFile(object):
 
     @classmethod
     def load(cls, fp):
-        return simplejson.load(fp)
+        return json.load(fp)
 
     @classmethod
     def dump(cls, obj):
-        return simplejson.dumps(obj)
+        return json.dumps(obj)
 
     @classmethod
     def from_file(cls, filename):
@@ -88,7 +88,7 @@ class InterfaceFile(object):
         except OSError:
             pass
 
-        interface_file = "{}.json".format(self.name)
+        interface_file = f"{self.name}.json"
 
         with os.fdopen(os.open(os.path.join(net_dir, interface_file),
                                flags, mode), 'w') as fp:
@@ -168,7 +168,7 @@ class VIPInterfaceFile(InterfaceFile):
             })
 
             vip_cidr = ipaddress.ip_network(
-                "{}/{}".format(vip['ip_address'], vip['prefixlen']),
+                f"{vip['ip_address']}/{vip['prefixlen']}",
                 strict=False)
             self.routes.append({
                 consts.DST: vip_cidr.exploded,
