@@ -32,7 +32,7 @@ CONF = cfg.CONF
 LOG = logging.getLogger(__name__)
 
 
-class PaginationHelper(object):
+class PaginationHelper:
     """Class helping to interact with pagination functionality
 
     Pass this class to `db.repositories` to apply it on query
@@ -142,40 +142,34 @@ class PaginationHelper(object):
 
     def _make_links(self, model_list):
         if CONF.api_settings.api_base_uri:
-            path_url = "{api_base_url}{path}".format(
-                api_base_url=CONF.api_settings.api_base_uri.rstrip('/'),
-                path=request.path)
+            path_url = (f"{CONF.api_settings.api_base_uri.rstrip('/')}"
+                        f"{request.path}")
         else:
             path_url = request.path_url
         links = []
         if model_list:
-            prev_attr = ["limit={}".format(self.limit)]
+            prev_attr = [f"limit={self.limit}"]
             if self.params.get('sort'):
-                prev_attr.append("sort={}".format(self.params.get('sort')))
+                prev_attr.append(f"sort={self.params.get('sort')}")
             if self.params.get('sort_key'):
-                prev_attr.append("sort_key={}".format(
-                    self.params.get('sort_key')))
+                prev_attr.append(f"sort_key={self.params.get('sort_key')}")
             next_attr = copy.copy(prev_attr)
             if self.marker:
-                prev_attr.append("marker={}".format(model_list[0].get('id')))
+                prev_attr.append(f"marker={model_list[0].get('id')}")
                 prev_attr.append("page_reverse=True")
                 prev_link = {
                     "rel": "previous",
-                    "href": "{url}?{params}".format(
-                        url=path_url,
-                        params="&".join(prev_attr))
+                    "href": f"{path_url}?{'&'.join(prev_attr)}"
                 }
                 links.append(prev_link)
             # TODO(rm_work) Do we need to know when there are more vs exact?
             # We safely know if we have a full page, but it might include the
             # last element or it might not, it is unclear
-            if len(model_list) >= self.limit:
-                next_attr.append("marker={}".format(model_list[-1].get('id')))
+            if self.limit is None or len(model_list) >= self.limit:
+                next_attr.append(f"marker={model_list[-1].get('id')}")
                 next_link = {
                     "rel": "next",
-                    "href": "{url}?{params}".format(
-                        url=path_url,
-                        params="&".join(next_attr))
+                    "href": f"{path_url}?{'&'.join(next_attr)}"
                 }
                 links.append(next_link)
         links = [types.PageType(**link) for link in links]
@@ -361,7 +355,7 @@ class PaginationHelper(object):
                         attr = sa_sql.expression.case(
                             (model_attr.isnot(None), model_attr),
                             else_=default)
-                        crit_attrs.append((attr == marker_values[j]))
+                        crit_attrs.append(attr == marker_values[j])
 
                     model_attr = getattr(model, self.sort_keys[i][0])
                     default = PaginationHelper._get_default_column_value(
@@ -372,14 +366,14 @@ class PaginationHelper(object):
                     this_sort_dir = self.sort_keys[i][1]
                     if this_sort_dir == constants.DESC:
                         if self.page_reverse == "True":
-                            crit_attrs.append((attr > marker_values[i]))
+                            crit_attrs.append(attr > marker_values[i])
                         else:
-                            crit_attrs.append((attr < marker_values[i]))
+                            crit_attrs.append(attr < marker_values[i])
                     elif this_sort_dir == constants.ASC:
                         if self.page_reverse == "True":
-                            crit_attrs.append((attr < marker_values[i]))
+                            crit_attrs.append(attr < marker_values[i])
                         else:
-                            crit_attrs.append((attr > marker_values[i]))
+                            crit_attrs.append(attr > marker_values[i])
                     else:
                         raise exceptions.InvalidSortDirection(
                             key=this_sort_dir)
