@@ -27,7 +27,7 @@ CONF = cfg.CONF
 LOG = logging.getLogger(__name__)
 
 
-class RootController(object):
+class RootController:
     """The controller with which the pecan wsgi app should be created."""
 
     def __init__(self):
@@ -65,7 +65,7 @@ class RootController(object):
         host_url = pecan_request.path_url
 
         if not host_url.endswith('/'):
-            host_url = '{}/'.format(host_url)
+            host_url = f'{host_url}/'
 
         versions = []
         self._add_a_version(versions, 'v2.0', 'v2', 'SUPPORTED',
@@ -148,7 +148,13 @@ class RootController(object):
         # HTTP Strict Transport Security (HSTS)
         self._add_a_version(versions, 'v2.27', 'v2', 'SUPPORTED',
                             '2023-05-05T00:00:00Z', host_url)
-        # Add port vnic_type for SR-IOV
-        self._add_a_version(versions, 'v2.28', 'v2', 'CURRENT',
+        # Add VIP port vnic_type for SR-IOV
+        self._add_a_version(versions, 'v2.28', 'v2', 'SUPPORTED',
                             '2023-11-08T00:00:00Z', host_url)
+        # Add VIP SGs
+        self._add_a_version(versions, 'v2.29', 'v2', 'SUPPORTED',
+                            '2024-10-15T00:00:00Z', host_url)
+        # Add member port SR-IOV support
+        self._add_a_version(versions, 'v2.30', 'v2', 'CURRENT',
+                            '2025-02-26T00:00:00Z', host_url)
         return {'versions': versions}
