@@ -22,6 +22,7 @@ import time
 from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_reports import guru_meditation_report as gmr
+from oslo_reports import opts as gmr_opts
 import setproctitle
 from stevedore import enabled as stevedore_enabled
 
@@ -55,10 +56,9 @@ def _process_wrapper(exit_event, proc_name, function, agent_name=None):
     signal.signal(signal.SIGINT, signal.SIG_IGN)
     signal.signal(signal.SIGHUP, _mutate_config)
     if agent_name:
-        process_title = 'octavia-driver-agent - {} -- {}'.format(
-            proc_name, agent_name)
+        process_title = f'octavia-driver-agent - {proc_name} -- {agent_name}'
     else:
-        process_title = 'octavia-driver-agent - {}'.format(proc_name)
+        process_title = f'octavia-driver-agent - {proc_name}'
     setproctitle.setproctitle(process_title)
     while not exit_event.is_set():
         try:
@@ -97,7 +97,8 @@ def main():
     LOG.debug('Full set of CONF:')
     CONF.log_opt_values(LOG, logging.DEBUG)
 
-    gmr.TextGuruMeditation.setup_autorun(version)
+    gmr_opts.set_defaults(CONF)
+    gmr.TextGuruMeditation.setup_autorun(version, conf=CONF)
 
     processes = []
     exit_event = multiprocessing.Event()
