@@ -26,6 +26,7 @@ from oslo_config import cfg
 from oslo_db import options as db_options
 from oslo_log import log as logging
 import oslo_messaging as messaging
+from oslo_middleware import cors
 from oslo_policy import opts as policy_opts
 
 from octavia.certificates.common import local
@@ -462,12 +463,12 @@ controller_worker_opts = [
                help=_('The timezone to use in the Amphora as represented in '
                       '/usr/share/zoneinfo.')),
     cfg.ListOpt('amp_boot_network_list',
-                default='',
+                default=[],
                 help=_('List of networks to attach to the Amphorae. '
                        'All networks defined in the list will '
                        'be attached to each amphora.')),
     cfg.ListOpt('amp_secgroup_list',
-                default='',
+                default=[],
                 help=_('List of security groups to attach to the Amphora.')),
     cfg.StrOpt('client_ca',
                default='/etc/octavia/certs/ca_01.pem',
@@ -545,7 +546,7 @@ task_flow_opts = [
                        'an inconsistent state and should only be used for '
                        'debugging purposes.')),
     cfg.StrOpt('persistence_connection',
-               default='sqlite://',
+               default='sqlite://', secret=True,
                help='Persistence database, which will be used to store tasks '
                     'states. Database connection url with db name'),
     cfg.BoolOpt('jobboard_enabled', default=False,
@@ -555,8 +556,10 @@ task_flow_opts = [
                choices=[('redis_taskflow_driver',
                          'Driver that will use Redis to store job states.'),
                         ('zookeeper_taskflow_driver',
-                         'Driver that will use Zookeeper to store job states.')
-                        ],
+                         'Driver that will use Zookeeper to store job '
+                         'states.'),
+                        ('etcd_taskflow_driver',
+                         'Driver that will user Etcd to store job states.')],
                help='Jobboard backend driver that will monitor job state.'),
     cfg.ListOpt('jobboard_backend_hosts', default=['127.0.0.1'],
                 help='Jobboard backend server host(s).'),
@@ -569,6 +572,9 @@ task_flow_opts = [
     cfg.StrOpt('jobboard_backend_namespace', default='octavia_jobboard',
                help='Jobboard name that should be used to store taskflow '
                     'job id and claims for it.'),
+    cfg.IntOpt('jobboard_redis_backend_db',
+               default=0, min=0,
+               help='Database ID in redis server.'),
     cfg.StrOpt('jobboard_redis_sentinel', default=None,
                help='Sentinel name if it is used for Redis.'),
     cfg.StrOpt('jobboard_redis_sentinel_username',
@@ -596,6 +602,16 @@ task_flow_opts = [
                          'keyfile_password': None,
                          'certfile': None,
                          'verify_certs': True}),
+    cfg.DictOpt('jobboard_etcd_ssl_options',
+                help='Etcd jobboard backend ssl configuration options.',
+                default={'use_ssl': False,
+                         'ca_cert': None,
+                         'cert_key': None,
+                         'cert_cert': None}),
+    cfg.IntOpt('jobboard_etcd_timeout', default=None,
+               help='Timeout when communicating with the Etcd backend.'),
+    cfg.StrOpt('jobboard_etcd_api_path', default=None,
+               help='API Path of the Etcd server.'),
     cfg.IntOpt('jobboard_expiration_time', default=30,
                help='For backends like redis claiming jobs requiring setting '
                     'the expiry - how many seconds the claim should be '
@@ -873,7 +889,7 @@ driver_agent_opts = [
                default=60,
                help=_('The time, in seconds, to wait for provider agents '
                       'to shutdown after the exit event has been set.')),
-    cfg.ListOpt('enabled_provider_agents', default='',
+    cfg.ListOpt('enabled_provider_agents', default=[],
                 help=_('List of enabled provider agents. The driver-agent '
                        'will launch these agents at startup.'))
 ]
@@ -1053,8 +1069,18 @@ def set_lib_defaults():
     generator.html#modifying-defaults-from-other-namespaces
     """
 
+    set_cors_middleware_defaults()
     # TODO(gmann): Remove setting the default value of config policy_file
     # once oslo_policy change the default value to 'policy.yaml'.
     # https://github.com/openstack/oslo.policy/blob/a626ad12fe5a3abd49d70e3e5b95589d279ab578/oslo_policy/opts.py#L49
     # Update default value of oslo.policy policy_file config option.
     policy_opts.set_defaults(cfg.CONF, 'policy.yaml')
+
+
+def set_cors_middleware_defaults():
+    """Update default configuration options for oslo.middleware."""
+    cors.set_defaults(
+        allow_headers=['X-Auth-Token', 'X-Openstack-Request-Id'],
+        allow_methods=['GET', 'PUT', 'POST', 'DELETE'],
+        expose_headers=['X-Auth-Token', 'X-Openstack-Request-Id']
+    )
