@@ -332,6 +332,7 @@ CODE = 'code'
 COMPUTE_ID = 'compute_id'
 COMPUTE_OBJ = 'compute_obj'
 COMPUTE_ZONE = 'compute_zone'
+VOLUME_ZONE = 'volume_zone'
 CONN_MAX_RETRIES = 'conn_max_retries'
 CONN_RETRY_INTERVAL = 'conn_retry_interval'
 CREATED_AT = 'created_at'
@@ -767,6 +768,10 @@ RULE_API_READ_QUOTA = 'rule:load-balancer:read-quota'
 RULE_API_READ_QUOTA_GLOBAL = 'rule:load-balancer:read-quota-global'
 RULE_API_WRITE_QUOTA = 'rule:load-balancer:write-quota'
 
+# The service user for Aodh needs to be able to list all
+# members of a pool to determine which are healthy.
+RULE_MEMBER_API_READ = f'{RULE_API_READ} or rule:service'
+
 RBAC_LOADBALANCER = f'{LOADBALANCER_API}:loadbalancer:'
 RBAC_LISTENER = f'{LOADBALANCER_API}:listener:'
 RBAC_POOL = f'{LOADBALANCER_API}:pool:'
@@ -891,13 +896,16 @@ CINDER_ACTION_CREATE_VOLUME = 'create volume'
 NIL_UUID = '00000000-0000-0000-0000-000000000000'
 
 # OpenSSL cipher strings
-CIPHERS_OWASP_SUITE_B = ('TLS_AES_256_GCM_SHA384:TLS_CHACHA20_POLY1305_SHA256:'
-                         'TLS_AES_128_GCM_SHA256:DHE-RSA-AES256-GCM-SHA384:'
-                         'DHE-RSA-AES128-GCM-SHA256:'
+CIPHERS_OWASP_SUITE_B = ('TLS_AES_128_GCM_SHA256:TLS_AES_256_GCM_SHA384:'
+                         'TLS_CHACHA20_POLY1305_SHA256:'
+                         'ECDHE-ECDSA-AES128-GCM-SHA256:'
+                         'ECDHE-RSA-AES128-GCM-SHA256:'
+                         'ECDHE-ECDSA-AES256-GCM-SHA384:'
                          'ECDHE-RSA-AES256-GCM-SHA384:'
-                         'ECDHE-RSA-AES128-GCM-SHA256:DHE-RSA-AES256-SHA256:'
-                         'DHE-RSA-AES128-SHA256:ECDHE-RSA-AES256-SHA384:'
-                         'ECDHE-RSA-AES128-SHA256')
+                         'ECDHE-ECDSA-CHACHA20-POLY1305:'
+                         'ECDHE-RSA-CHACHA20-POLY1305:'
+                         'DHE-RSA-AES128-GCM-SHA256:DHE-RSA-AES256-GCM-SHA384:'
+                         'DHE-RSA-CHACHA20-POLY1305')
 
 TLS_VERSIONS_OWASP_SUITE_B = [lib_consts.TLS_VERSION_1_2,
                               lib_consts.TLS_VERSION_1_3]
