@@ -25,7 +25,7 @@ TEMPLATES_DIR = (os.path.dirname(os.path.realpath(__file__)) +
                  constants.TEMPLATES + '/')
 
 
-class UserDataJinjaCfg(object):
+class UserDataJinjaCfg:
 
     def __init__(self):
         template_loader = jinja2.FileSystemLoader(searchpath=os.path.dirname(
@@ -35,4 +35,5 @@ class UserDataJinjaCfg(object):
             constants.USER_DATA_CONFIG_DRIVE_TEMPLATE)
 
     def build_user_data_config(self, user_data):
-        return self.agent_template.render(user_data=user_data)
+        return self.agent_template.render(
+            user_data=user_data, timezone=CONF.controller_worker.amp_timezone)
