@@ -113,9 +113,6 @@ class ListenerFlows:
         delete_listener_flow = linear_flow.Flow(
             constants.DELETE_LISTENER_FLOW + '-' + listener_id)
         # Should cascade delete all L7 policies
-        delete_listener_flow.add(network_tasks.UpdateVIPForDelete(
-            name='delete_update_vip_' + listener_id,
-            requires=constants.LOADBALANCER_ID))
         delete_listener_flow.add(database_tasks.DeleteListenerInDB(
             name='delete_listener_in_db_' + listener_id,
             requires=constants.LISTENER,
@@ -176,7 +173,8 @@ class ListenerFlows:
 
         fw_rules_subflow.add(
             amphora_driver_tasks.AmphoraeGetConnectivityStatus(
-                name=constants.AMPHORAE_GET_CONNECTIVITY_STATUS,
+                name=(sf_name + '-' +
+                      constants.AMPHORAE_GET_CONNECTIVITY_STATUS),
                 requires=constants.AMPHORAE,
                 inject={constants.TIMEOUT_DICT: timeout_dict,
                         constants.NEW_AMPHORA_ID: constants.NIL_UUID},
