@@ -314,7 +314,8 @@ class HandleNetworkDelta(BaseNetworkTask):
                     raise base.NetworkNotFound(str(e))
                 raise base.CreatePortException(str(e))
             except Exception as e:
-                message = _(f'Error creating a port on network {network_id}. ')
+                message = _('Error creating a port on network {network_id}.'
+                            ).format(network_id=network_id)
                 LOG.exception(message)
                 raise base.CreatePortException(message) from e
 
@@ -728,7 +729,11 @@ class GetAmphoraNetworkConfigs(BaseNetworkTask):
             db_lb, amphora=db_amp)
         provider_dict = {}
         for amp_id, amp_conf in db_configs.items():
-            provider_dict[amp_id] = amp_conf.to_dict(recurse=True)
+            # Do not serialize loadbalancer class.  It's unused later and
+            # could be ignored for storing in results of task in persistence DB
+            provider_dict[amp_id] = amp_conf.to_dict(
+                recurse=True, calling_classes=[data_models.LoadBalancer]
+            )
         return provider_dict
 
 
@@ -746,7 +751,11 @@ class GetAmphoraNetworkConfigsByID(BaseNetworkTask):
                                                              amphora=amphora)
         provider_dict = {}
         for amp_id, amp_conf in db_configs.items():
-            provider_dict[amp_id] = amp_conf.to_dict(recurse=True)
+            # Do not serialize loadbalancer class.  It's unused later and
+            # could be ignored for storing in results of task in persistence DB
+            provider_dict[amp_id] = amp_conf.to_dict(
+                recurse=True, calling_classes=[data_models.LoadBalancer]
+            )
         return provider_dict
 
 
@@ -762,7 +771,11 @@ class GetAmphoraeNetworkConfigs(BaseNetworkTask):
         db_configs = self.network_driver.get_network_configs(db_lb)
         provider_dict = {}
         for amp_id, amp_conf in db_configs.items():
-            provider_dict[amp_id] = amp_conf.to_dict(recurse=True)
+            # Do not serialize loadbalancer class.  It's unused later and
+            # could be ignored for storing in results of task in persistence DB
+            provider_dict[amp_id] = amp_conf.to_dict(
+                recurse=True, calling_classes=[data_models.LoadBalancer]
+            )
         return provider_dict
 
 
