@@ -30,5 +30,5 @@ down_revision = '458c9ee2a011'
 
 
 def upgrade():
-    op.add_column(u'load_balancer', sa.Column(u'server_group_id',
-                                              sa.String(36), nullable=True))
+    op.add_column('load_balancer', sa.Column('server_group_id',
+                                             sa.String(36), nullable=True))
