@@ -21,20 +21,20 @@ Create Date: 2015-01-20 13:31:30.017959
 
 """
 
-# revision identifiers, used by Alembic.
-revision = '48660b6643f0'
-down_revision = '3e5b37a0bdb9'
-
 from alembic import op
 import sqlalchemy as sa
 from sqlalchemy import sql
 
+# revision identifiers, used by Alembic.
+revision = '48660b6643f0'
+down_revision = '3e5b37a0bdb9'
+
 
 def upgrade():
     insert_table = sql.table(
-        u'provisioning_status',
-        sql.column(u'name', sa.String),
-        sql.column(u'description', sa.String)
+        'provisioning_status',
+        sql.column('name', sa.String),
+        sql.column('description', sa.String)
     )
 
     op.bulk_insert(
@@ -45,7 +45,3 @@ def upgrade():
             {'name': 'ALLOCATED'}
         ]
     )
-
-
-def downgrade():
-    pass
