@@ -31,6 +31,6 @@ down_revision = 'a7f187cd221f'
 def upgrade():
     # Add column redirect_prefix
     op.add_column(
-        u'l7policy',
-        sa.Column(u'redirect_http_code', sa.Integer(), nullable=True)
+        'l7policy',
+        sa.Column('redirect_http_code', sa.Integer(), nullable=True)
     )
