@@ -42,7 +42,7 @@ class KeepalivedLvsTestCase(base.TestCase):
         "# Configuration for Listener %(listener_id)s\n\n"
         "net_namespace haproxy-amphora\n\n"
         "virtual_server 10.0.0.2 80 {\n"
-        "    lb_algo wrr\n"
+        "    lb_algo rr\n"
         "    lb_kind NAT\n"
         "    protocol udp\n"
         "    delay_loop 30\n"
@@ -97,7 +97,7 @@ class KeepalivedLvsTestCase(base.TestCase):
     TEST_URL = server.PATH_PREFIX + '/listeners/%s/%s/udp_listener'
 
     def setUp(self):
-        super(KeepalivedLvsTestCase, self).setUp()
+        super().setUp()
         self.app = flask.Flask(__name__)
         self.client = self.app.test_client()
         self._ctx = self.app.test_request_context()
@@ -106,7 +106,7 @@ class KeepalivedLvsTestCase(base.TestCase):
         self.app.add_url_rule(
             rule=self.TEST_URL % ('<amphora_id>', '<listener_id>'),
             view_func=(lambda amphora_id, listener_id:
-                       self.test_keepalivedlvs.upload_udp_listener_config(
+                       self.test_keepalivedlvs.upload_lvs_listener_config(
                            listener_id)),
             methods=['PUT'])
 
@@ -116,17 +116,14 @@ class KeepalivedLvsTestCase(base.TestCase):
                 'install_netns_systemd_service')
     @mock.patch('pyroute2.NetNS', create=True)
     @mock.patch('shutil.copy2')
-    @mock.patch('octavia.amphorae.backends.agent.api_server.util.'
-                'get_os_init_system', return_value=consts.INIT_SYSTEMD)
     @mock.patch('os.chmod')
     @mock.patch('os.path.exists')
     @mock.patch('os.makedirs')
     @mock.patch('os.remove')
     @mock.patch('subprocess.check_output')
-    def test_upload_udp_listener_config_no_vrrp_check_dir(
+    def test_upload_lvs_listener_config_no_vrrp_check_dir(
             self, m_check_output, m_os_rm, m_os_mkdir, m_exists, m_os_chmod,
-            m_os_sysinit, m_copy2, mock_netns, mock_install_netns,
-            mock_systemctl):
+            m_copy2, mock_netns, mock_install_netns, mock_systemctl):
         m_exists.side_effect = [False, False, True, True, False, False]
         cfg_path = util.keepalived_lvs_cfg_path(self.FAKE_ID)
         m = self.useFixture(test_utils.OpenFixture(cfg_path)).mock_open
@@ -143,9 +140,10 @@ class KeepalivedLvsTestCase(base.TestCase):
             mock_install_netns.assert_called_once()
             systemctl_calls = [
                 mock.call(consts.ENABLE,
-                          consts.AMP_NETNS_SVC_PREFIX),
-                mock.call(consts.ENABLE,
-                          'octavia-keepalivedlvs-%s' % str(self.FAKE_ID)),
+                          consts.AMP_NETNS_SVC_PREFIX, False),
+                mock.call(
+                    consts.ENABLE,
+                    'octavia-keepalivedlvs-%s.service' % self.FAKE_ID),
             ]
             mock_systemctl.assert_has_calls(systemctl_calls)
             os_mkdir_calls = [
@@ -159,8 +157,7 @@ class KeepalivedLvsTestCase(base.TestCase):
 
             flags = os.O_WRONLY | os.O_CREAT | os.O_TRUNC
             mode = stat.S_IRUSR | stat.S_IWUSR | stat.S_IRGRP | stat.S_IROTH
-            systemd_cfg_path = util.keepalived_lvs_init_path(
-                consts.INIT_SYSTEMD, self.FAKE_ID)
+            systemd_cfg_path = util.keepalived_lvs_init_path(self.FAKE_ID)
 
             m_open_calls = [
                 mock.call(cfg_path, flags, mode),
@@ -172,7 +169,7 @@ class KeepalivedLvsTestCase(base.TestCase):
             self.assertEqual(200, res.status_code)
 
     @mock.patch('octavia.amphorae.backends.agent.api_server.util.'
-                'get_udp_listeners')
+                'get_lvs_listeners')
     @mock.patch('octavia.amphorae.backends.agent.api_server.util.'
                 'get_loadbalancers')
     @mock.patch('octavia.amphorae.backends.agent.api_server.util.'
@@ -181,20 +178,18 @@ class KeepalivedLvsTestCase(base.TestCase):
                 'install_netns_systemd_service')
     @mock.patch('pyroute2.NetNS', create=True)
     @mock.patch('shutil.copy2')
-    @mock.patch('octavia.amphorae.backends.agent.api_server.util.'
-                'get_os_init_system', return_value=consts.INIT_SYSTEMD)
     @mock.patch('os.chmod')
     @mock.patch('os.path.exists')
     @mock.patch('os.makedirs')
     @mock.patch('os.remove')
     @mock.patch('subprocess.check_output')
-    def test_upload_udp_listener_config_with_vrrp_check_dir(
+    def test_upload_lvs_listener_config_with_vrrp_check_dir(
             self, m_check_output, m_os_rm, m_os_mkdir, m_exists, m_os_chmod,
-            m_os_sysinit, m_copy2, mock_netns, mock_install_netns,
-            mock_systemctl, mock_get_lbs, mock_get_udp_listeners):
+            m_copy2, mock_netns, mock_install_netns, mock_systemctl,
+            mock_get_lbs, mock_get_lvs_listeners):
         m_exists.side_effect = [False, False, True, True, False, False, False]
         mock_get_lbs.return_value = []
-        mock_get_udp_listeners.return_value = [self.FAKE_ID]
+        mock_get_lvs_listeners.return_value = [self.FAKE_ID]
         cfg_path = util.keepalived_lvs_cfg_path(self.FAKE_ID)
         m = self.useFixture(test_utils.OpenFixture(cfg_path)).mock_open
 
@@ -219,9 +214,10 @@ class KeepalivedLvsTestCase(base.TestCase):
             mock_install_netns.assert_called_once()
             systemctl_calls = [
                 mock.call(consts.ENABLE,
-                          consts.AMP_NETNS_SVC_PREFIX),
-                mock.call(consts.ENABLE,
-                          'octavia-keepalivedlvs-%s' % str(self.FAKE_ID)),
+                          consts.AMP_NETNS_SVC_PREFIX, False),
+                mock.call(
+                    consts.ENABLE,
+                    'octavia-keepalivedlvs-%s.service' % self.FAKE_ID)
             ]
             mock_systemctl.assert_has_calls(systemctl_calls)
 
@@ -229,8 +225,7 @@ class KeepalivedLvsTestCase(base.TestCase):
                 util.keepalived_backend_check_script_path(), stat.S_IEXEC)
             flags = os.O_WRONLY | os.O_CREAT | os.O_TRUNC
             mode = stat.S_IRUSR | stat.S_IWUSR | stat.S_IRGRP | stat.S_IROTH
-            systemd_cfg_path = util.keepalived_lvs_init_path(
-                consts.INIT_SYSTEMD, self.FAKE_ID)
+            systemd_cfg_path = util.keepalived_lvs_init_path(self.FAKE_ID)
             script_path = os.path.join(
                 util.keepalived_check_scripts_dir(),
                 keepalivedlvs.KEEPALIVED_CHECK_SCRIPT_NAME)
@@ -252,16 +247,14 @@ class KeepalivedLvsTestCase(base.TestCase):
     @mock.patch('octavia.amphorae.backends.agent.api_server.util.'
                 'install_netns_systemd_service')
     @mock.patch('shutil.copy2')
-    @mock.patch('octavia.amphorae.backends.agent.api_server.util.'
-                'get_os_init_system', return_value=consts.INIT_SYSTEMD)
     @mock.patch('os.chmod')
     @mock.patch('os.path.exists')
     @mock.patch('os.makedirs')
     @mock.patch('os.remove')
     @mock.patch('subprocess.check_output')
-    def test_upload_udp_listener_config_start_service_failure(
+    def test_upload_lvs_listener_config_start_service_failure(
             self, m_check_output, m_os_rm, m_os_mkdir, m_exists, m_os_chmod,
-            m_os_sysinit, m_copy2, mock_install_netns, mock_systemctl):
+            m_copy2, mock_install_netns, mock_systemctl):
         m_exists.side_effect = [False, False, True, True, False]
         cfg_path = util.keepalived_lvs_cfg_path(self.FAKE_ID)
         m = self.useFixture(test_utils.OpenFixture(cfg_path)).mock_open
@@ -283,9 +276,10 @@ class KeepalivedLvsTestCase(base.TestCase):
             mock_install_netns.assert_called_once()
             systemctl_calls = [
                 mock.call(consts.ENABLE,
-                          consts.AMP_NETNS_SVC_PREFIX),
-                mock.call(consts.ENABLE,
-                          'octavia-keepalivedlvs-%s' % str(self.FAKE_ID)),
+                          consts.AMP_NETNS_SVC_PREFIX, False),
+                mock.call(
+                    consts.ENABLE,
+                    'octavia-keepalivedlvs-%s.service' % self.FAKE_ID)
             ]
             mock_systemctl.assert_has_calls(systemctl_calls)
 
@@ -293,8 +287,7 @@ class KeepalivedLvsTestCase(base.TestCase):
                 util.keepalived_backend_check_script_path(), stat.S_IEXEC)
             flags = os.O_WRONLY | os.O_CREAT | os.O_TRUNC
             mode = stat.S_IRUSR | stat.S_IWUSR | stat.S_IRGRP | stat.S_IROTH
-            systemd_cfg_path = util.keepalived_lvs_init_path(
-                consts.INIT_SYSTEMD, self.FAKE_ID)
+            systemd_cfg_path = util.keepalived_lvs_init_path(self.FAKE_ID)
             m_open_calls = [
                 mock.call(cfg_path, flags, mode),
                 mock.call(systemd_cfg_path, flags, mode)
@@ -307,62 +300,62 @@ class KeepalivedLvsTestCase(base.TestCase):
     @mock.patch('subprocess.check_output')
     @mock.patch('octavia.amphorae.backends.agent.api_server.'
                 'keepalivedlvs.KeepalivedLvs.'
-                '_check_udp_listener_exists')
-    def test_manage_udp_listener(self, mock_udp_exist, mock_check_output):
-        res = self.test_keepalivedlvs.manage_udp_listener(self.FAKE_ID,
+                '_check_lvs_listener_exists')
+    def test_manage_lvs_listener(self, mock_lvs_exist, mock_check_output):
+        res = self.test_keepalivedlvs.manage_lvs_listener(self.FAKE_ID,
                                                           'start')
-        cmd = ("/usr/sbin/service octavia-keepalivedlvs-{listener_id}"
-               " {action}".format(listener_id=self.FAKE_ID, action='start'))
+        cmd = f"systemctl start octavia-keepalivedlvs-{self.FAKE_ID}.service"
         mock_check_output.assert_called_once_with(cmd.split(),
-                                                  stderr=subprocess.STDOUT)
+                                                  stderr=subprocess.STDOUT,
+                                                  encoding='utf-8')
         self.assertEqual(202, res.status_code)
 
-        res = self.test_keepalivedlvs.manage_udp_listener(self.FAKE_ID,
+        res = self.test_keepalivedlvs.manage_lvs_listener(self.FAKE_ID,
                                                           'restart')
         self.assertEqual(400, res.status_code)
 
         mock_check_output.side_effect = subprocess.CalledProcessError(1,
                                                                       'blah!')
 
-        res = self.test_keepalivedlvs.manage_udp_listener(self.FAKE_ID,
+        res = self.test_keepalivedlvs.manage_lvs_listener(self.FAKE_ID,
                                                           'start')
         self.assertEqual(500, res.status_code)
 
     @mock.patch('octavia.amphorae.backends.agent.api_server.util.'
-                'get_udp_listeners', return_value=[LISTENER_ID])
-    @mock.patch('octavia.amphorae.backends.agent.api_server.util.'
-                'get_os_init_system', return_value=consts.INIT_SYSTEMD)
+                'get_lvs_listeners', return_value=[LISTENER_ID])
     @mock.patch('octavia.amphorae.backends.agent.api_server.util.'
                 'get_keepalivedlvs_pid', return_value="12345")
     @mock.patch('subprocess.check_output')
     @mock.patch('os.remove')
     @mock.patch('os.path.exists')
-    def test_delete_udp_listener(self, m_exist, m_remove, m_check_output,
-                                 mget_pid, m_init_sys, mget_udp_listeners):
+    def test_delete_lvs_listener(self, m_exist, m_remove, m_check_output,
+                                 mget_pid, mget_lvs_listeners):
         m_exist.return_value = True
-        res = self.test_keepalivedlvs.delete_udp_listener(self.FAKE_ID)
+        res = self.test_keepalivedlvs.delete_lvs_listener(self.FAKE_ID)
 
-        cmd1 = ("/usr/sbin/service "
-                "octavia-keepalivedlvs-{0} stop".format(self.FAKE_ID))
+        cmd1 = f"systemctl stop octavia-keepalivedlvs-{self.FAKE_ID}.service"
         cmd2 = ("systemctl disable "
-                "octavia-keepalivedlvs-{list}".format(list=self.FAKE_ID))
+                f"octavia-keepalivedlvs-{self.FAKE_ID}.service")
         calls = [
-            mock.call(cmd1.split(), stderr=subprocess.STDOUT),
-            mock.call(cmd2.split(), stderr=subprocess.STDOUT)
+            mock.call(cmd1.split(), stderr=subprocess.STDOUT,
+                      encoding='utf-8'),
+            mock.call(cmd2.split(), stderr=subprocess.STDOUT,
+                      encoding='utf-8')
         ]
         m_check_output.assert_has_calls(calls)
         self.assertEqual(200, res.status_code)
 
     @mock.patch.object(keepalivedlvs, "webob")
     @mock.patch('os.path.exists')
-    def test_delete_udp_listener_not_exist(self, m_exist, m_webob):
+    def test_delete_lvs_listener_not_exist(self, m_exist, m_webob):
         m_exist.return_value = False
-        self.test_keepalivedlvs.delete_udp_listener(self.FAKE_ID)
+        self.test_keepalivedlvs.delete_lvs_listener(self.FAKE_ID)
         calls = [
             mock.call(
-                json=dict(message='UDP Listener Not Found',
-                          details="No UDP listener with UUID: "
-                                  "{0}".format(self.FAKE_ID)), status=404),
+                json=dict(
+                    message='UDP Listener Not Found',
+                    details=f"No UDP listener with UUID: {self.FAKE_ID}"
+                ), status=404),
             mock.call(json={'message': 'OK'})
         ]
         m_webob.Response.assert_has_calls(calls)
@@ -371,48 +364,31 @@ class KeepalivedLvsTestCase(base.TestCase):
                 'get_keepalivedlvs_pid', return_value="12345")
     @mock.patch('subprocess.check_output')
     @mock.patch('os.path.exists')
-    def test_delete_udp_listener_stop_service_fail(self, m_exist,
+    def test_delete_lvs_listener_stop_service_fail(self, m_exist,
                                                    m_check_output, mget_pid):
         m_exist.return_value = True
         m_check_output.side_effect = subprocess.CalledProcessError(1,
                                                                    'Woops!')
-        res = self.test_keepalivedlvs.delete_udp_listener(self.FAKE_ID)
+        res = self.test_keepalivedlvs.delete_lvs_listener(self.FAKE_ID)
         self.assertEqual(500, res.status_code)
         self.assertEqual({'message': 'Error stopping keepalivedlvs',
                           'details': None}, res.json)
 
-    @mock.patch('octavia.amphorae.backends.agent.api_server.util.'
-                'get_os_init_system', return_value=consts.INIT_SYSVINIT)
     @mock.patch('octavia.amphorae.backends.agent.api_server.util.'
                 'get_keepalivedlvs_pid', return_value="12345")
     @mock.patch('subprocess.check_output')
     @mock.patch('os.remove')
     @mock.patch('os.path.exists')
-    def test_delete_udp_listener_disable_service_fail(self, m_exist, m_remove,
-                                                      m_check_output, mget_pid,
-                                                      m_init_sys):
+    def test_delete_lvs_listener_disable_service_fail(self, m_exist, m_remove,
+                                                      m_check_output,
+                                                      mget_pid):
         m_exist.return_value = True
         m_check_output.side_effect = [True,
                                       subprocess.CalledProcessError(
                                           1, 'Woops!')]
-        res = self.test_keepalivedlvs.delete_udp_listener(self.FAKE_ID)
+        res = self.test_keepalivedlvs.delete_lvs_listener(self.FAKE_ID)
         self.assertEqual(500, res.status_code)
         self.assertEqual({
-            'message': 'Error disabling '
-                       'octavia-keepalivedlvs-%s service' % self.FAKE_ID,
+            'message': f'Error disabling octavia-keepalivedlvs-{self.FAKE_ID} '
+                       f'service',
             'details': None}, res.json)
-
-    @mock.patch('octavia.amphorae.backends.agent.api_server.util.'
-                'get_os_init_system')
-    @mock.patch('octavia.amphorae.backends.agent.api_server.util.'
-                'get_keepalivedlvs_pid', return_value="12345")
-    @mock.patch('subprocess.check_output')
-    @mock.patch('os.remove')
-    @mock.patch('os.path.exists')
-    def test_delete_udp_listener_unsupported_sysinit(self, m_exist, m_remove,
-                                                     m_check_output, mget_pid,
-                                                     m_init_sys):
-        m_exist.return_value = True
-        self.assertRaises(
-            util.UnknownInitError, self.test_keepalivedlvs.delete_udp_listener,
-            self.FAKE_ID)
