@@ -40,6 +40,7 @@ class TestAmphora(base.BaseAPITest):
         self.project_id = self.lb.get('project_id')
         self.set_lb_status(self.lb_id)
         self.amp_args = {
+            'id': uuidutils.generate_uuid(),
             'load_balancer_id': self.lb_id,
             'compute_id': uuidutils.generate_uuid(),
             'lb_network_ip': '192.168.1.2',
@@ -91,9 +92,11 @@ class TestAmphora(base.BaseAPITest):
                                     'total_connections': 9}
         self.ref_amp_stats = [self.listener1_amp_stats,
                               self.listener2_amp_stats]
+        self.session.commit()
 
     def _create_additional_amp(self):
         amp_args = {
+            'id': uuidutils.generate_uuid(),
             'load_balancer_id': None,
             'compute_id': uuidutils.generate_uuid(),
             'lb_network_ip': '192.168.1.2',
@@ -109,7 +112,8 @@ class TestAmphora(base.BaseAPITest):
             'vrrp_id': 1,
             'vrrp_priority': 100,
         }
-        return self.amphora_repo.create(self.session, **amp_args)
+        with self.session.begin():
+            return self.amphora_repo.create(self.session, **amp_args)
 
     def _assert_amp_equal(self, source, response):
         self.assertEqual(source.pop('load_balancer_id'),
@@ -130,9 +134,11 @@ class TestAmphora(base.BaseAPITest):
     @mock.patch('oslo_messaging.RPCClient.cast')
     def test_delete(self, mock_cast):
         self.amp_args = {
+            'id': uuidutils.generate_uuid(),
             'status': constants.AMPHORA_READY,
         }
-        amp = self.amphora_repo.create(self.session, **self.amp_args)
+        with self.session.begin():
+            amp = self.amphora_repo.create(self.session, **self.amp_args)
 
         self.delete(self.AMPHORA_PATH.format(
             amphora_id=amp.id), status=204)
@@ -154,9 +160,11 @@ class TestAmphora(base.BaseAPITest):
     @mock.patch('oslo_messaging.RPCClient.cast')
     def test_delete_immutable(self, mock_cast):
         self.amp_args = {
+            'id': uuidutils.generate_uuid(),
             'status': constants.AMPHORA_ALLOCATED,
         }
-        amp = self.amphora_repo.create(self.session, **self.amp_args)
+        with self.session.begin():
+            amp = self.amphora_repo.create(self.session, **self.amp_args)
 
         self.delete(self.AMPHORA_PATH.format(
             amphora_id=amp.id), status=409)
@@ -166,34 +174,33 @@ class TestAmphora(base.BaseAPITest):
     @mock.patch('oslo_messaging.RPCClient.cast')
     def test_delete_authorized(self, mock_cast):
         self.amp_args = {
+            'id': uuidutils.generate_uuid(),
             'status': constants.AMPHORA_READY,
         }
-        amp = self.amphora_repo.create(self.session, **self.amp_args)
+        with self.session.begin():
+            amp = self.amphora_repo.create(self.session, **self.amp_args)
 
         self.conf = self.useFixture(oslo_fixture.Config(cfg.CONF))
         auth_strategy = self.conf.conf.api_settings.get('auth_strategy')
         self.conf.config(group='api_settings', auth_strategy=constants.TESTING)
-        with mock.patch.object(octavia.common.context.RequestContext,
-                               'project_id',
-                               self.project_id):
-            override_credentials = {
-                'service_user_id': None,
-                'user_domain_id': None,
-                'is_admin_project': True,
-                'service_project_domain_id': None,
-                'service_project_id': None,
-                'roles': ['load-balancer_member'],
-                'user_id': None,
-                'is_admin': True,
-                'service_user_domain_id': None,
-                'project_domain_id': None,
-                'service_roles': [],
-                'project_id': self.project_id}
-            with mock.patch(
-                    "oslo_context.context.RequestContext.to_policy_values",
-                    return_value=override_credentials):
-                self.delete(self.AMPHORA_PATH.format(amphora_id=amp.id),
-                            status=204)
+        override_credentials = {
+            'service_user_id': None,
+            'user_domain_id': None,
+            'is_admin_project': True,
+            'service_project_domain_id': None,
+            'service_project_id': None,
+            'roles': ['load-balancer_member'],
+            'user_id': None,
+            'is_admin': True,
+            'service_user_domain_id': None,
+            'project_domain_id': None,
+            'service_roles': [],
+            'project_id': self.project_id}
+        with mock.patch(
+                "oslo_context.context.RequestContext.to_policy_values",
+                return_value=override_credentials):
+            self.delete(self.AMPHORA_PATH.format(amphora_id=amp.id),
+                        status=204)
         # Reset api auth setting
         self.conf.config(group='api_settings', auth_strategy=auth_strategy)
 
@@ -208,16 +215,19 @@ class TestAmphora(base.BaseAPITest):
     @mock.patch('oslo_messaging.RPCClient.cast')
     def test_delete_not_authorized(self, mock_cast):
         self.amp_args = {
+            'id': uuidutils.generate_uuid(),
             'status': constants.AMPHORA_READY,
         }
-        amp = self.amphora_repo.create(self.session, **self.amp_args)
+        with self.session.begin():
+            amp = self.amphora_repo.create(self.session, **self.amp_args)
 
         self.conf = self.useFixture(oslo_fixture.Config(cfg.CONF))
         auth_strategy = self.conf.conf.api_settings.get('auth_strategy')
         self.conf.config(group='api_settings', auth_strategy=constants.TESTING)
-        with mock.patch.object(octavia.common.context.RequestContext,
-                               'project_id',
-                               self.project_id):
+        test_context = octavia.common.context.RequestContext(
+            project_id=self.project_id)
+        with mock.patch('oslo_context.context.RequestContext.from_environ',
+                        return_value=test_context):
             self.delete(self.AMPHORA_PATH.format(amphora_id=amp.id),
                         status=403)
         # Reset api auth setting
@@ -249,27 +259,24 @@ class TestAmphora(base.BaseAPITest):
         self.conf = self.useFixture(oslo_fixture.Config(cfg.CONF))
         auth_strategy = self.conf.conf.api_settings.get('auth_strategy')
         self.conf.config(group='api_settings', auth_strategy=constants.TESTING)
-        with mock.patch.object(octavia.common.context.RequestContext,
-                               'project_id',
-                               self.project_id):
-            override_credentials = {
-                'service_user_id': None,
-                'user_domain_id': None,
-                'is_admin_project': True,
-                'service_project_domain_id': None,
-                'service_project_id': None,
-                'roles': ['load-balancer_member'],
-                'user_id': None,
-                'is_admin': True,
-                'service_user_domain_id': None,
-                'project_domain_id': None,
-                'service_roles': [],
-                'project_id': self.project_id}
-            with mock.patch(
-                    "oslo_context.context.RequestContext.to_policy_values",
-                    return_value=override_credentials):
-                response = self.get(self.AMPHORA_PATH.format(
-                    amphora_id=self.amp_id)).json.get(self.root_tag)
+        override_credentials = {
+            'service_user_id': None,
+            'user_domain_id': None,
+            'is_admin_project': True,
+            'service_project_domain_id': None,
+            'service_project_id': None,
+            'roles': ['load-balancer_member'],
+            'user_id': None,
+            'is_admin': True,
+            'service_user_domain_id': None,
+            'project_domain_id': None,
+            'service_roles': [],
+            'project_id': self.project_id}
+        with mock.patch(
+                "oslo_context.context.RequestContext.to_policy_values",
+                return_value=override_credentials):
+            response = self.get(self.AMPHORA_PATH.format(
+                amphora_id=self.amp_id)).json.get(self.root_tag)
         # Reset api auth setting
         self.conf.config(group='api_settings', auth_strategy=auth_strategy)
 
@@ -279,9 +286,10 @@ class TestAmphora(base.BaseAPITest):
         self.conf = self.useFixture(oslo_fixture.Config(cfg.CONF))
         auth_strategy = self.conf.conf.api_settings.get('auth_strategy')
         self.conf.config(group='api_settings', auth_strategy=constants.TESTING)
-        with mock.patch.object(octavia.common.context.RequestContext,
-                               'project_id',
-                               uuidutils.generate_uuid()):
+        test_context = octavia.common.context.RequestContext(
+            project_id=uuidutils.generate_uuid())
+        with mock.patch('oslo_context.context.RequestContext.from_environ',
+                        return_value=test_context):
             response = self.get(self.AMPHORA_PATH.format(
                 amphora_id=self.amp_id), status=403)
         # Reset api auth setting
@@ -293,27 +301,24 @@ class TestAmphora(base.BaseAPITest):
         self.conf = self.useFixture(oslo_fixture.Config(cfg.CONF))
         auth_strategy = self.conf.conf.api_settings.get('auth_strategy')
         self.conf.config(group='api_settings', auth_strategy=constants.TESTING)
-        with mock.patch.object(octavia.common.context.RequestContext,
-                               'project_id',
-                               self.project_id):
-            override_credentials = {
-                'service_user_id': None,
-                'user_domain_id': None,
-                'is_admin_project': True,
-                'service_project_domain_id': None,
-                'service_project_id': None,
-                'roles': ['load-balancer_member'],
-                'user_id': None,
-                'is_admin': True,
-                'service_user_domain_id': None,
-                'project_domain_id': None,
-                'service_roles': [],
-                'project_id': self.project_id}
-            with mock.patch(
-                    "oslo_context.context.RequestContext.to_policy_values",
-                    return_value=override_credentials):
-                self.put(self.AMPHORA_FAILOVER_PATH.format(
-                    amphora_id=self.amp_id), body={}, status=202)
+        override_credentials = {
+            'service_user_id': None,
+            'user_domain_id': None,
+            'is_admin_project': True,
+            'service_project_domain_id': None,
+            'service_project_id': None,
+            'roles': ['load-balancer_member'],
+            'user_id': None,
+            'is_admin': True,
+            'service_user_domain_id': None,
+            'project_domain_id': None,
+            'service_roles': [],
+            'project_id': self.project_id}
+        with mock.patch(
+                "oslo_context.context.RequestContext.to_policy_values",
+                return_value=override_credentials):
+            self.put(self.AMPHORA_FAILOVER_PATH.format(
+                amphora_id=self.amp_id), body={}, status=202)
 
         # Reset api auth setting
         self.conf.config(group='api_settings', auth_strategy=auth_strategy)
@@ -325,9 +330,10 @@ class TestAmphora(base.BaseAPITest):
         self.conf = self.useFixture(oslo_fixture.Config(cfg.CONF))
         auth_strategy = self.conf.conf.api_settings.get('auth_strategy')
         self.conf.config(group='api_settings', auth_strategy=constants.TESTING)
-        with mock.patch.object(octavia.common.context.RequestContext,
-                               'project_id',
-                               uuidutils.generate_uuid()):
+        test_context = octavia.common.context.RequestContext(
+            project_id=uuidutils.generate_uuid())
+        with mock.patch('oslo_context.context.RequestContext.from_environ',
+                        return_value=test_context):
             response = self.put(self.AMPHORA_FAILOVER_PATH.format(
                 amphora_id=self.amp_id), body={}, status=403)
         # Reset api auth setting
@@ -355,27 +361,24 @@ class TestAmphora(base.BaseAPITest):
     def test_get_all_authorized(self):
         auth_strategy = self.conf.conf.api_settings.get('auth_strategy')
         self.conf.config(group='api_settings', auth_strategy=constants.TESTING)
-        with mock.patch.object(octavia.common.context.RequestContext,
-                               'project_id',
-                               uuidutils.generate_uuid()):
-            override_credentials = {
-                'service_user_id': None,
-                'user_domain_id': None,
-                'is_admin_project': True,
-                'service_project_domain_id': None,
-                'service_project_id': None,
-                'roles': ['load-balancer_member'],
-                'user_id': None,
-                'is_admin': True,
-                'service_user_domain_id': None,
-                'project_domain_id': None,
-                'service_roles': [],
-                'project_id': self.project_id}
-            with mock.patch(
-                    "oslo_context.context.RequestContext.to_policy_values",
-                    return_value=override_credentials):
-                amps = self.get(self.AMPHORAE_PATH).json.get(
-                    self.root_tag_list)
+        override_credentials = {
+            'service_user_id': None,
+            'user_domain_id': None,
+            'is_admin_project': True,
+            'service_project_domain_id': None,
+            'service_project_id': None,
+            'roles': ['load-balancer_member'],
+            'user_id': None,
+            'is_admin': True,
+            'service_user_domain_id': None,
+            'project_domain_id': None,
+            'service_roles': [],
+            'project_id': self.project_id}
+        with mock.patch(
+                "oslo_context.context.RequestContext.to_policy_values",
+                return_value=override_credentials):
+            amps = self.get(self.AMPHORAE_PATH).json.get(
+                self.root_tag_list)
 
         self.conf.config(group='api_settings', auth_strategy=auth_strategy)
         self.assertIsInstance(amps, list)
@@ -385,9 +388,10 @@ class TestAmphora(base.BaseAPITest):
     def test_get_all_not_authorized(self):
         auth_strategy = self.conf.conf.api_settings.get('auth_strategy')
         self.conf.config(group='api_settings', auth_strategy=constants.TESTING)
-        with mock.patch.object(octavia.common.context.RequestContext,
-                               'project_id',
-                               uuidutils.generate_uuid()):
+        test_context = octavia.common.context.RequestContext(
+            project_id=uuidutils.generate_uuid())
+        with mock.patch('oslo_context.context.RequestContext.from_environ',
+                        return_value=test_context):
             amps = self.get(self.AMPHORAE_PATH, status=403).json
 
         self.conf.config(group='api_settings', auth_strategy=auth_strategy)
@@ -488,17 +492,17 @@ class TestAmphora(base.BaseAPITest):
         amps = self.get(self.AMPHORAE_PATH, params={
             'fields': ['id', 'role']}).json
         for amp in amps['amphorae']:
-            self.assertIn(u'id', amp)
-            self.assertIn(u'role', amp)
-            self.assertNotIn(u'ha_port_id', amp)
+            self.assertIn('id', amp)
+            self.assertIn('role', amp)
+            self.assertNotIn('ha_port_id', amp)
 
     def test_get_one_fields_filter(self):
         amp = self.get(
             self.AMPHORA_PATH.format(amphora_id=self.amp_id),
             params={'fields': ['id', 'role']}).json.get(self.root_tag)
-        self.assertIn(u'id', amp)
-        self.assertIn(u'role', amp)
-        self.assertNotIn(u'ha_port_id', amp)
+        self.assertIn('id', amp)
+        self.assertIn('role', amp)
+        self.assertNotIn('ha_port_id', amp)
 
     def test_get_all_filter(self):
         self._create_additional_amp()
@@ -519,27 +523,24 @@ class TestAmphora(base.BaseAPITest):
         self.conf = self.useFixture(oslo_fixture.Config(cfg.CONF))
         auth_strategy = self.conf.conf.api_settings.get('auth_strategy')
         self.conf.config(group='api_settings', auth_strategy=constants.TESTING)
-        with mock.patch.object(octavia.common.context.RequestContext,
-                               'project_id',
-                               self.project_id):
-            override_credentials = {
-                'service_user_id': None,
-                'user_domain_id': None,
-                'is_admin_project': True,
-                'service_project_domain_id': None,
-                'service_project_id': None,
-                'roles': ['load-balancer_member'],
-                'user_id': None,
-                'is_admin': True,
-                'service_user_domain_id': None,
-                'project_domain_id': None,
-                'service_roles': [],
-                'project_id': self.project_id}
-            with mock.patch(
-                    "oslo_context.context.RequestContext.to_policy_values",
-                    return_value=override_credentials):
-                response = self.get(self.AMPHORA_STATS_PATH.format(
-                    amphora_id=self.amp_id)).json.get(self.root_tag_stats)
+        override_credentials = {
+            'service_user_id': None,
+            'user_domain_id': None,
+            'is_admin_project': True,
+            'service_project_domain_id': None,
+            'service_project_id': None,
+            'roles': ['load-balancer_member'],
+            'user_id': None,
+            'is_admin': True,
+            'service_user_domain_id': None,
+            'project_domain_id': None,
+            'service_roles': [],
+            'project_id': self.project_id}
+        with mock.patch(
+                "oslo_context.context.RequestContext.to_policy_values",
+                return_value=override_credentials):
+            response = self.get(self.AMPHORA_STATS_PATH.format(
+                amphora_id=self.amp_id)).json.get(self.root_tag_stats)
         # Reset api auth setting
         self.conf.config(group='api_settings', auth_strategy=auth_strategy)
         self.assertEqual(self.ref_amp_stats, response)
@@ -548,9 +549,10 @@ class TestAmphora(base.BaseAPITest):
         self.conf = self.useFixture(oslo_fixture.Config(cfg.CONF))
         auth_strategy = self.conf.conf.api_settings.get('auth_strategy')
         self.conf.config(group='api_settings', auth_strategy=constants.TESTING)
-        with mock.patch.object(octavia.common.context.RequestContext,
-                               'project_id',
-                               uuidutils.generate_uuid()):
+        test_context = octavia.common.context.RequestContext(
+            project_id=uuidutils.generate_uuid())
+        with mock.patch('oslo_context.context.RequestContext.from_environ',
+                        return_value=test_context):
             response = self.get(self.AMPHORA_STATS_PATH.format(
                 amphora_id=self.amp_id), status=403)
         # Reset api auth setting
@@ -567,6 +569,7 @@ class TestAmphora(base.BaseAPITest):
         self.lb2_id = self.lb2.get('id')
         self.set_lb_status(self.lb2_id)
         self.amp2_args = {
+            'id': uuidutils.generate_uuid(),
             'load_balancer_id': self.lb2_id,
             'compute_id': uuidutils.generate_uuid(),
             'lb_network_ip': '192.168.1.20',
@@ -625,28 +628,25 @@ class TestAmphora(base.BaseAPITest):
         self.conf = self.useFixture(oslo_fixture.Config(cfg.CONF))
         auth_strategy = self.conf.conf.api_settings.get('auth_strategy')
         self.conf.config(group='api_settings', auth_strategy=constants.TESTING)
-        with mock.patch.object(octavia.common.context.RequestContext,
-                               'project_id',
-                               self.project_id):
-            override_credentials = {
-                'service_user_id': None,
-                'user_domain_id': None,
-                'is_admin_project': True,
-                'service_project_domain_id': None,
-                'service_project_id': None,
-                'roles': ['load-balancer_member'],
-                'user_id': None,
-                'is_admin': True,
-                'service_user_domain_id': None,
-                'project_domain_id': None,
-                'service_roles': [],
-                'project_id': self.project_id}
-            with mock.patch(
-                    "oslo_context.context.RequestContext.to_policy_values",
-                    return_value=override_credentials):
+        override_credentials = {
+            'service_user_id': None,
+            'user_domain_id': None,
+            'is_admin_project': True,
+            'service_project_domain_id': None,
+            'service_project_id': None,
+            'roles': ['load-balancer_member'],
+            'user_id': None,
+            'is_admin': True,
+            'service_user_domain_id': None,
+            'project_domain_id': None,
+            'service_roles': [],
+            'project_id': self.project_id}
+        with mock.patch(
+                "oslo_context.context.RequestContext.to_policy_values",
+                return_value=override_credentials):
 
-                self.put(self.AMPHORA_CONFIG_PATH.format(
-                    amphora_id=self.amp_id), body={}, status=202)
+            self.put(self.AMPHORA_CONFIG_PATH.format(
+                amphora_id=self.amp_id), body={}, status=202)
         # Reset api auth setting
         self.conf.config(group='api_settings', auth_strategy=auth_strategy)
         payload = {constants.AMPHORA_ID: self.amp_id}
@@ -658,9 +658,10 @@ class TestAmphora(base.BaseAPITest):
         self.conf = self.useFixture(oslo_fixture.Config(cfg.CONF))
         auth_strategy = self.conf.conf.api_settings.get('auth_strategy')
         self.conf.config(group='api_settings', auth_strategy=constants.TESTING)
-        with mock.patch.object(octavia.common.context.RequestContext,
-                               'project_id',
-                               uuidutils.generate_uuid()):
+        test_context = octavia.common.context.RequestContext(
+            project_id=uuidutils.generate_uuid())
+        with mock.patch('oslo_context.context.RequestContext.from_environ',
+                        return_value=test_context):
             self.put(self.AMPHORA_CONFIG_PATH.format(
                 amphora_id=self.amp_id), body={}, status=403)
         # Reset api auth setting
