@@ -67,26 +67,24 @@ class TestL7Rule(base.BaseAPITest):
         self.conf = self.useFixture(oslo_fixture.Config(cfg.CONF))
         auth_strategy = self.conf.conf.api_settings.get('auth_strategy')
         self.conf.config(group='api_settings', auth_strategy=constants.TESTING)
-        with mock.patch.object(octavia.common.context.Context, 'project_id',
-                               self.project_id):
-            override_credentials = {
-                'service_user_id': None,
-                'user_domain_id': None,
-                'is_admin_project': True,
-                'service_project_domain_id': None,
-                'service_project_id': None,
-                'roles': ['load-balancer_member'],
-                'user_id': None,
-                'is_admin': False,
-                'service_user_domain_id': None,
-                'project_domain_id': None,
-                'service_roles': [],
-                'project_id': self.project_id}
-            with mock.patch(
-                    "oslo_context.context.RequestContext.to_policy_values",
-                    return_value=override_credentials):
-                response = self.get(self.l7rule_path.format(
-                    l7rule_id=l7rule.get('id'))).json.get(self.root_tag)
+        override_credentials = {
+            'service_user_id': None,
+            'user_domain_id': None,
+            'is_admin_project': True,
+            'service_project_domain_id': None,
+            'service_project_id': None,
+            'roles': ['load-balancer_member', 'member'],
+            'user_id': None,
+            'is_admin': False,
+            'service_user_domain_id': None,
+            'project_domain_id': None,
+            'service_roles': [],
+            'project_id': self.project_id}
+        with mock.patch(
+                "oslo_context.context.RequestContext.to_policy_values",
+                return_value=override_credentials):
+            response = self.get(self.l7rule_path.format(
+                l7rule_id=l7rule.get('id'))).json.get(self.root_tag)
         self.conf.config(group='api_settings', auth_strategy=auth_strategy)
         self.assertEqual(l7rule, response)
 
@@ -98,8 +96,10 @@ class TestL7Rule(base.BaseAPITest):
         self.conf = self.useFixture(oslo_fixture.Config(cfg.CONF))
         auth_strategy = self.conf.conf.api_settings.get('auth_strategy')
         self.conf.config(group='api_settings', auth_strategy=constants.TESTING)
-        with mock.patch.object(octavia.common.context.Context, 'project_id',
-                               self.project_id):
+        test_context = octavia.common.context.RequestContext(
+            project_id=self.project_id)
+        with mock.patch('oslo_context.context.RequestContext.from_environ',
+                        return_value=test_context):
             response = self.get(self.l7rule_path.format(
                 l7rule_id=l7rule.get('id')), status=403).json
         self.conf.config(group='api_settings', auth_strategy=auth_strategy)
@@ -164,26 +164,24 @@ class TestL7Rule(base.BaseAPITest):
         self.conf = self.useFixture(oslo_fixture.Config(cfg.CONF))
         auth_strategy = self.conf.conf.api_settings.get('auth_strategy')
         self.conf.config(group='api_settings', auth_strategy=constants.TESTING)
-        with mock.patch.object(octavia.common.context.Context, 'project_id',
-                               self.project_id):
-            override_credentials = {
-                'service_user_id': None,
-                'user_domain_id': None,
-                'is_admin_project': True,
-                'service_project_domain_id': None,
-                'service_project_id': None,
-                'roles': ['load-balancer_member'],
-                'user_id': None,
-                'is_admin': False,
-                'service_user_domain_id': None,
-                'project_domain_id': None,
-                'service_roles': [],
-                'project_id': self.project_id}
-            with mock.patch(
-                    "oslo_context.context.RequestContext.to_policy_values",
-                    return_value=override_credentials):
-                rules = self.get(
-                    self.l7rules_path).json.get(self.root_tag_list)
+        override_credentials = {
+            'service_user_id': None,
+            'user_domain_id': None,
+            'is_admin_project': True,
+            'service_project_domain_id': None,
+            'service_project_id': None,
+            'roles': ['load-balancer_member', 'member'],
+            'user_id': None,
+            'is_admin': False,
+            'service_user_domain_id': None,
+            'project_domain_id': None,
+            'service_roles': [],
+            'project_id': self.project_id}
+        with mock.patch(
+                "oslo_context.context.RequestContext.to_policy_values",
+                return_value=override_credentials):
+            rules = self.get(
+                self.l7rules_path).json.get(self.root_tag_list)
 
         self.conf.config(group='api_settings', auth_strategy=auth_strategy)
         self.assertIsInstance(rules, list)
@@ -208,25 +206,23 @@ class TestL7Rule(base.BaseAPITest):
         self.conf = self.useFixture(oslo_fixture.Config(cfg.CONF))
         auth_strategy = self.conf.conf.api_settings.get('auth_strategy')
         self.conf.config(group='api_settings', auth_strategy=constants.TESTING)
-        with mock.patch.object(octavia.common.context.Context, 'project_id',
-                               None):
-            override_credentials = {
-                'service_user_id': None,
-                'user_domain_id': None,
-                'is_admin_project': True,
-                'service_project_domain_id': None,
-                'service_project_id': None,
-                'roles': ['load-balancer_member'],
-                'user_id': None,
-                'is_admin': False,
-                'service_user_domain_id': None,
-                'project_domain_id': None,
-                'service_roles': [],
-                'project_id': None}
-            with mock.patch(
-                    "oslo_context.context.RequestContext.to_policy_values",
-                    return_value=override_credentials):
-                result = self.get(self.l7rules_path, status=403).json
+        override_credentials = {
+            'service_user_id': None,
+            'user_domain_id': None,
+            'is_admin_project': True,
+            'service_project_domain_id': None,
+            'service_project_id': None,
+            'roles': ['load-balancer_member'],
+            'user_id': None,
+            'is_admin': False,
+            'service_user_domain_id': None,
+            'project_domain_id': None,
+            'service_roles': [],
+            'project_id': None}
+        with mock.patch(
+                "oslo_context.context.RequestContext.to_policy_values",
+                return_value=override_credentials):
+            result = self.get(self.l7rules_path, status=403).json
         self.conf.config(group='api_settings', auth_strategy=auth_strategy)
         self.assertEqual(self.NOT_AUTHORIZED_BODY, result)
 
@@ -244,8 +240,10 @@ class TestL7Rule(base.BaseAPITest):
         self.conf = self.useFixture(oslo_fixture.Config(cfg.CONF))
         auth_strategy = self.conf.conf.api_settings.get('auth_strategy')
         self.conf.config(group='api_settings', auth_strategy=constants.TESTING)
-        with mock.patch.object(octavia.common.context.Context, 'project_id',
-                               self.project_id):
+        test_context = octavia.common.context.RequestContext(
+            project_id=self.project_id)
+        with mock.patch('oslo_context.context.RequestContext.from_environ',
+                        return_value=test_context):
             rules = self.get(self.l7rules_path, status=403)
 
         self.conf.config(group='api_settings', auth_strategy=auth_strategy)
@@ -351,9 +349,9 @@ class TestL7Rule(base.BaseAPITest):
         l7rus = self.get(self.l7rules_path, params={
             'fields': ['id', 'compare_type']}).json
         for l7ru in l7rus['rules']:
-            self.assertIn(u'id', l7ru)
-            self.assertIn(u'compare_type', l7ru)
-            self.assertNotIn(u'project_id', l7ru)
+            self.assertIn('id', l7ru)
+            self.assertIn('compare_type', l7ru)
+            self.assertNotIn('project_id', l7ru)
 
     def test_get_one_fields_filter(self):
         l7r1 = self.create_l7rule(
@@ -365,9 +363,9 @@ class TestL7Rule(base.BaseAPITest):
         l7ru = self.get(
             self.l7rule_path.format(l7rule_id=l7r1.get('id')),
             params={'fields': ['id', 'compare_type']}).json.get(self.root_tag)
-        self.assertIn(u'id', l7ru)
-        self.assertIn(u'compare_type', l7ru)
-        self.assertNotIn(u'project_id', l7ru)
+        self.assertIn('id', l7ru)
+        self.assertIn('compare_type', l7ru)
+        self.assertNotIn('project_id', l7ru)
 
     def test_get_all_filter(self):
         ru1 = self.create_l7rule(
@@ -528,28 +526,26 @@ class TestL7Rule(base.BaseAPITest):
         auth_strategy = self.conf.conf.api_settings.get('auth_strategy')
         self.conf.config(group='api_settings', auth_strategy=constants.TESTING)
 
-        with mock.patch.object(octavia.common.context.Context, 'project_id',
-                               self.project_id):
-            override_credentials = {
-                'service_user_id': None,
-                'user_domain_id': None,
-                'is_admin_project': True,
-                'service_project_domain_id': None,
-                'service_project_id': None,
-                'roles': ['load-balancer_member'],
-                'user_id': None,
-                'is_admin': False,
-                'service_user_domain_id': None,
-                'project_domain_id': None,
-                'service_roles': [],
-                'project_id': self.project_id}
-            with mock.patch(
-                    "oslo_context.context.RequestContext.to_policy_values",
-                    return_value=override_credentials):
-                api_l7rule = self.create_l7rule(
-                    self.l7policy_id, constants.L7RULE_TYPE_HOST_NAME,
-                    constants.L7RULE_COMPARE_TYPE_EQUAL_TO,
-                    'www.example.com').get(self.root_tag)
+        override_credentials = {
+            'service_user_id': None,
+            'user_domain_id': None,
+            'is_admin_project': True,
+            'service_project_domain_id': None,
+            'service_project_id': None,
+            'roles': ['load-balancer_member', 'member'],
+            'user_id': None,
+            'is_admin': False,
+            'service_user_domain_id': None,
+            'project_domain_id': None,
+            'service_roles': [],
+            'project_id': self.project_id}
+        with mock.patch(
+                "oslo_context.context.RequestContext.to_policy_values",
+                return_value=override_credentials):
+            api_l7rule = self.create_l7rule(
+                self.l7policy_id, constants.L7RULE_TYPE_HOST_NAME,
+                constants.L7RULE_COMPARE_TYPE_EQUAL_TO,
+                'www.example.com').get(self.root_tag)
         self.conf.config(group='api_settings', auth_strategy=auth_strategy)
         self.assertEqual(constants.L7RULE_TYPE_HOST_NAME,
                          api_l7rule.get('type'))
@@ -572,8 +568,10 @@ class TestL7Rule(base.BaseAPITest):
         auth_strategy = self.conf.conf.api_settings.get('auth_strategy')
         self.conf.config(group='api_settings', auth_strategy=constants.TESTING)
 
-        with mock.patch.object(octavia.common.context.Context, 'project_id',
-                               self.project_id):
+        test_context = octavia.common.context.RequestContext(
+            project_id=self.project_id)
+        with mock.patch('oslo_context.context.RequestContext.from_environ',
+                        return_value=test_context):
             api_l7rule = self.create_l7rule(
                 self.l7policy_id, constants.L7RULE_TYPE_HOST_NAME,
                 constants.L7RULE_COMPARE_TYPE_EQUAL_TO,
@@ -592,8 +590,7 @@ class TestL7Rule(base.BaseAPITest):
             l7policy_id, constants.L7RULE_TYPE_HOST_NAME,
             constants.L7RULE_COMPARE_TYPE_EQUAL_TO,
             'www.example.com', status=409)
-        ref_msg = ('L7Policy %s is immutable and cannot be updated.' %
-                   l7policy_id)
+        ref_msg = f'L7Policy {l7policy_id} is immutable and cannot be updated.'
         self.assertEqual(ref_msg, api_l7rule.get('faultstring'))
 
     def test_create_path_rule(self):
@@ -790,7 +787,7 @@ class TestL7Rule(base.BaseAPITest):
                   'key': 'no-need-key'}
         response = req_func(first_req_arg, self._build_body(l7rule),
                             status=400).json
-        self.assertIn('L7rule type {0} does not use the "key" field.'.format(
+        self.assertIn('L7rule type {} does not use the "key" field.'.format(
             constants.L7RULE_TYPE_SSL_CONN_HAS_CERT),
             response.get('faultstring'))
 
@@ -799,7 +796,7 @@ class TestL7Rule(base.BaseAPITest):
         response = req_func(first_req_arg, self._build_body(l7rule),
                             status=400).json
         self.assertIn(
-            'L7rule value {0} is not a boolean True string.'.format(
+            'L7rule value {} is not a boolean True string.'.format(
                 l7rule['value']), response.get('faultstring'))
 
         l7rule['value'] = 'tRUe'
@@ -807,7 +804,7 @@ class TestL7Rule(base.BaseAPITest):
         response = req_func(first_req_arg, self._build_body(l7rule),
                             status=400).json
         self.assertIn(
-            'L7rule type {0} only supports the {1} compare type.'.format(
+            'L7rule type {} only supports the {} compare type.'.format(
                 constants.L7RULE_TYPE_SSL_CONN_HAS_CERT,
                 constants.L7RULE_COMPARE_TYPE_EQUAL_TO),
             response.get('faultstring'))
@@ -822,14 +819,14 @@ class TestL7Rule(base.BaseAPITest):
         response = req_func(first_req_arg, self._build_body(l7rule),
                             status=400).json
         self.assertIn(
-            'L7rule type {0} does not use the "key" field.'.format(
+            'L7rule type {} does not use the "key" field.'.format(
                 l7rule['type']), response.get('faultstring'))
 
         l7rule.pop('key')
         response = req_func(first_req_arg, self._build_body(l7rule),
                             status=400).json
         self.assertIn(
-            'L7rule type {0} needs a int value, which is >= 0'.format(
+            'L7rule type {} needs a int value, which is >= 0'.format(
                 l7rule['type']), response.get('faultstring'))
 
         l7rule['value'] = '0'
@@ -837,7 +834,7 @@ class TestL7Rule(base.BaseAPITest):
         response = req_func(first_req_arg, self._build_body(l7rule),
                             status=400).json
         self.assertIn(
-            'L7rule type {0} only supports the {1} compare type.'.format(
+            'L7rule type {} only supports the {} compare type.'.format(
                 l7rule['type'], constants.L7RULE_COMPARE_TYPE_EQUAL_TO),
             response.get('faultstring'))
 
@@ -854,7 +851,7 @@ class TestL7Rule(base.BaseAPITest):
         response = req_func(first_req_arg, self._build_body(l7rule),
                             status=400).json
         self.assertIn(
-            'L7rule type {0} needs to specify a key and a value.'.format(
+            'L7rule type {} needs to specify a key and a value.'.format(
                 l7rule['type']), response.get('faultstring'))
 
         l7rule['key'] = 'NOT_SUPPORTED_DN_FIELD'
@@ -906,27 +903,25 @@ class TestL7Rule(base.BaseAPITest):
         self.conf = self.useFixture(oslo_fixture.Config(cfg.CONF))
         auth_strategy = self.conf.conf.api_settings.get('auth_strategy')
         self.conf.config(group='api_settings', auth_strategy=constants.TESTING)
-        with mock.patch.object(octavia.common.context.Context, 'project_id',
-                               self.project_id):
-            override_credentials = {
-                'service_user_id': None,
-                'user_domain_id': None,
-                'is_admin_project': True,
-                'service_project_domain_id': None,
-                'service_project_id': None,
-                'roles': ['load-balancer_member'],
-                'user_id': None,
-                'is_admin': False,
-                'service_user_domain_id': None,
-                'project_domain_id': None,
-                'service_roles': [],
-                'project_id': self.project_id}
-            with mock.patch(
-                    "oslo_context.context.RequestContext.to_policy_values",
-                    return_value=override_credentials):
-                response = self.put(self.l7rule_path.format(
-                    l7rule_id=api_l7rule.get('id')),
-                    self._build_body(new_l7rule)).json.get(self.root_tag)
+        override_credentials = {
+            'service_user_id': None,
+            'user_domain_id': None,
+            'is_admin_project': True,
+            'service_project_domain_id': None,
+            'service_project_id': None,
+            'roles': ['load-balancer_member', 'member'],
+            'user_id': None,
+            'is_admin': False,
+            'service_user_domain_id': None,
+            'project_domain_id': None,
+            'service_roles': [],
+            'project_id': self.project_id}
+        with mock.patch(
+                "oslo_context.context.RequestContext.to_policy_values",
+                return_value=override_credentials):
+            response = self.put(self.l7rule_path.format(
+                l7rule_id=api_l7rule.get('id')),
+                self._build_body(new_l7rule)).json.get(self.root_tag)
         self.conf.config(group='api_settings', auth_strategy=auth_strategy)
         self.assertEqual('/images', response.get('value'))
         self.assert_correct_status(
@@ -948,8 +943,10 @@ class TestL7Rule(base.BaseAPITest):
         self.conf = self.useFixture(oslo_fixture.Config(cfg.CONF))
         auth_strategy = self.conf.conf.api_settings.get('auth_strategy')
         self.conf.config(group='api_settings', auth_strategy=constants.TESTING)
-        with mock.patch.object(octavia.common.context.Context, 'project_id',
-                               self.project_id):
+        test_context = octavia.common.context.RequestContext(
+            project_id=self.project_id)
+        with mock.patch('oslo_context.context.RequestContext.from_environ',
+                        return_value=test_context):
             response = self.put(self.l7rule_path.format(
                 l7rule_id=api_l7rule.get('id')),
                 self._build_body(new_l7rule), status=403)
@@ -1108,27 +1105,25 @@ class TestL7Rule(base.BaseAPITest):
         self.conf = self.useFixture(oslo_fixture.Config(cfg.CONF))
         auth_strategy = self.conf.conf.api_settings.get('auth_strategy')
         self.conf.config(group='api_settings', auth_strategy=constants.TESTING)
-        with mock.patch.object(octavia.common.context.Context, 'project_id',
-                               self.project_id):
-            override_credentials = {
-                'service_user_id': None,
-                'user_domain_id': None,
-                'is_admin_project': True,
-                'service_project_domain_id': None,
-                'service_project_id': None,
-                'roles': ['load-balancer_member'],
-                'user_id': None,
-                'is_admin': False,
-                'service_user_domain_id': None,
-                'project_domain_id': None,
-                'service_roles': [],
-                'project_id': self.project_id}
-            with mock.patch(
-                    "oslo_context.context.RequestContext.to_policy_values",
-                    return_value=override_credentials):
+        override_credentials = {
+            'service_user_id': None,
+            'user_domain_id': None,
+            'is_admin_project': True,
+            'service_project_domain_id': None,
+            'service_project_id': None,
+            'roles': ['load-balancer_member', 'member'],
+            'user_id': None,
+            'is_admin': False,
+            'service_user_domain_id': None,
+            'project_domain_id': None,
+            'service_roles': [],
+            'project_id': self.project_id}
+        with mock.patch(
+                "oslo_context.context.RequestContext.to_policy_values",
+                return_value=override_credentials):
 
-                self.delete(
-                    self.l7rule_path.format(l7rule_id=api_l7rule.get('id')))
+            self.delete(
+                self.l7rule_path.format(l7rule_id=api_l7rule.get('id')))
         self.conf.config(group='api_settings', auth_strategy=auth_strategy)
         self.assert_correct_status(
             lb_id=self.lb_id, listener_id=self.listener_id,
@@ -1158,8 +1153,10 @@ class TestL7Rule(base.BaseAPITest):
         self.conf = self.useFixture(oslo_fixture.Config(cfg.CONF))
         auth_strategy = self.conf.conf.api_settings.get('auth_strategy')
         self.conf.config(group='api_settings', auth_strategy=constants.TESTING)
-        with mock.patch.object(octavia.common.context.Context, 'project_id',
-                               self.project_id):
+        test_context = octavia.common.context.RequestContext(
+            project_id=self.project_id)
+        with mock.patch('oslo_context.context.RequestContext.from_environ',
+                        return_value=test_context):
             self.delete(
                 self.l7rule_path.format(l7rule_id=api_l7rule.get('id')),
                 status=403)
@@ -1304,3 +1301,19 @@ class TestL7Rule(base.BaseAPITest):
         self.set_lb_status(self.lb_id, status=constants.DELETED)
         self.delete(self.l7rule_path.format(l7rule_id=l7rule.get('id')),
                     status=404)
+
+    @mock.patch("octavia.api.drivers.noop_driver.driver.NoopManager."
+                "l7rule_create")
+    def test_create_with_exception_in_provider_driver(self,
+                                                      l7rule_create_mock):
+        l7rule_create_mock.side_effect = Exception("Provider error")
+
+        self.create_l7rule(
+            self.l7policy_id, constants.L7RULE_TYPE_PATH,
+            constants.L7RULE_COMPARE_TYPE_STARTS_WITH,
+            '/api', status=500)
+
+        lb = self.get(self.LB_PATH.format(lb_id=self.lb_id)).json.get(
+            "loadbalancer")
+        self.assertEqual(lb[constants.PROVISIONING_STATUS],
+                         constants.ACTIVE)
