@@ -155,36 +155,36 @@ class TestAmphoraInfo(base.TestCase):
         m_count.return_value = 5
         original_version = api_server.VERSION
         api_server.VERSION = self.API_VERSION
-        expected_dict = {u'active': True,
+        expected_dict = {'active': True,
                          'active_tuned_profiles': '',
-                         u'api_version': self.API_VERSION,
-                         u'cpu': {u'soft_irq': u'8336',
-                                  u'system': u'52554',
-                                  u'total': 7503411,
-                                  u'user': u'252551'},
+                         'api_version': self.API_VERSION,
+                         'cpu': {'soft_irq': '8336',
+                                 'system': '52554',
+                                 'total': 7503411,
+                                 'user': '252551'},
                          'cpu_count': os.cpu_count(),
-                         u'disk': {u'available': 109079126016,
-                                   u'used': 25718685696},
-                         u'haproxy_count': 5,
-                         u'haproxy_version': self.HAPROXY_VERSION,
-                         u'hostname': u'FAKE_HOST',
-                         u'listeners': sorted([self.FAKE_LISTENER_ID_1,
-                                               self.FAKE_LISTENER_ID_2]),
-                         u'load': [u'0.09', u'0.11', u'0.10'],
-                         u'memory': {u'buffers': 344792,
-                                     u'cached': 4271856,
-                                     u'free': 12685624,
-                                     u'shared': 9520,
-                                     u'slab': 534384,
-                                     u'swap_used': 0,
-                                     u'total': 21692784},
-                         u'networks': {u'eth1': {u'network_rx': 996,
-                                                 u'network_tx': 418},
-                                       u'eth2': {u'network_rx': 848,
-                                                 u'network_tx': 578}},
-                         u'packages': {},
-                         u'topology': u'SINGLE',
-                         u'topology_status': u'OK'}
+                         'disk': {'available': 109079126016,
+                                  'used': 25718685696},
+                         'haproxy_count': 5,
+                         'haproxy_version': self.HAPROXY_VERSION,
+                         'hostname': 'FAKE_HOST',
+                         'listeners': sorted([self.FAKE_LISTENER_ID_1,
+                                              self.FAKE_LISTENER_ID_2]),
+                         'load': ['0.09', '0.11', '0.10'],
+                         'memory': {'buffers': 344792,
+                                    'cached': 4271856,
+                                    'free': 12685624,
+                                    'shared': 9520,
+                                    'slab': 534384,
+                                    'swap_used': 0,
+                                    'total': 21692784},
+                         'networks': {'eth1': {'network_rx': 996,
+                                               'network_tx': 418},
+                                      'eth2': {'network_rx': 848,
+                                               'network_tx': 578}},
+                         'packages': {},
+                         'topology': 'SINGLE',
+                         'topology_status': 'OK'}
         self.useFixture(test_utils.OpenFixture('/etc/tuned/active_profile'))
         actual = self.amp_info.compile_amphora_details()
         self.assertEqual(expected_dict, actual.json)
@@ -243,41 +243,40 @@ class TestAmphoraInfo(base.TestCase):
         mock_get_lb.return_value = [self.LB_ID_1]
         original_version = api_server.VERSION
         api_server.VERSION = self.API_VERSION
-        expected_dict = {u'active': True,
+        expected_dict = {'active': True,
                          'active_tuned_profiles': '',
-                         u'api_version': self.API_VERSION,
-                         u'cpu': {u'soft_irq': u'8336',
-                                  u'system': u'52554',
-                                  u'total': 7503411,
-                                  u'user': u'252551'},
+                         'api_version': self.API_VERSION,
+                         'cpu': {'soft_irq': '8336',
+                                 'system': '52554',
+                                 'total': 7503411,
+                                 'user': '252551'},
                          'cpu_count': os.cpu_count(),
-                         u'disk': {u'available': 109079126016,
-                                   u'used': 25718685696},
-                         u'haproxy_count': 5,
-                         u'haproxy_version': self.HAPROXY_VERSION,
-                         u'keepalived_version': self.KEEPALIVED_VERSION,
-                         u'ipvsadm_version': self.IPVSADM_VERSION,
-                         u'lvs_listener_process_count': 1,
-                         u'hostname': u'FAKE_HOST',
-                         u'listeners': sorted(list(set(
-                             [self.FAKE_LISTENER_ID_3,
-                              self.FAKE_LISTENER_ID_4,
-                              'sample_listener_id_1']))),
-                         u'load': [u'0.09', u'0.11', u'0.10'],
-                         u'memory': {u'buffers': 344792,
-                                     u'cached': 4271856,
-                                     u'free': 12685624,
-                                     u'shared': 9520,
-                                     u'slab': 534384,
-                                     u'swap_used': 0,
-                                     u'total': 21692784},
-                         u'networks': {u'eth1': {u'network_rx': 996,
-                                                 u'network_tx': 418},
-                                       u'eth2': {u'network_rx': 848,
-                                                 u'network_tx': 578}},
-                         u'packages': {},
-                         u'topology': u'SINGLE',
-                         u'topology_status': u'OK'}
+                         'disk': {'available': 109079126016,
+                                  'used': 25718685696},
+                         'haproxy_count': 5,
+                         'haproxy_version': self.HAPROXY_VERSION,
+                         'keepalived_version': self.KEEPALIVED_VERSION,
+                         'ipvsadm_version': self.IPVSADM_VERSION,
+                         'lvs_listener_process_count': 1,
+                         'hostname': 'FAKE_HOST',
+                         'listeners': sorted(list({self.FAKE_LISTENER_ID_3,
+                                                   self.FAKE_LISTENER_ID_4,
+                                                   'sample_listener_id_1'})),
+                         'load': ['0.09', '0.11', '0.10'],
+                         'memory': {'buffers': 344792,
+                                    'cached': 4271856,
+                                    'free': 12685624,
+                                    'shared': 9520,
+                                    'slab': 534384,
+                                    'swap_used': 0,
+                                    'total': 21692784},
+                         'networks': {'eth1': {'network_rx': 996,
+                                               'network_tx': 418},
+                                      'eth2': {'network_rx': 848,
+                                               'network_tx': 578}},
+                         'packages': {},
+                         'topology': 'SINGLE',
+                         'topology_status': 'OK'}
         self.useFixture(test_utils.OpenFixture('/etc/tuned/active_profile'))
         actual = self.amp_info.compile_amphora_details(self.lvs_driver)
         self.assertEqual(expected_dict, actual.json)
