@@ -12,6 +12,7 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 #
+import json
 import os
 import queue
 from unittest import mock
@@ -19,7 +20,6 @@ from unittest import mock
 from oslo_config import cfg
 from oslo_config import fixture as oslo_fixture
 from oslo_utils import uuidutils
-import simplejson
 
 from octavia.amphorae.backends.health_daemon import health_daemon
 from octavia.common import constants
@@ -337,7 +337,7 @@ class TestHealthDaemon(base.TestCase):
                                  mock_get_stats, mock_is_running):
         health_daemon.COUNTERS = None
         health_daemon.COUNTERS_FILE = None
-        lb1_stats_socket = '/var/lib/octavia/{0}/haproxy.sock'.format(LB_ID1)
+        lb1_stats_socket = f'/var/lib/octavia/{LB_ID1}/haproxy.sock'
         mock_list_files.return_value = {LB_ID1: lb1_stats_socket}
 
         mock_is_running.return_value = True
@@ -345,7 +345,7 @@ class TestHealthDaemon(base.TestCase):
 
         with mock.patch('os.open'), mock.patch.object(
                 os, 'fdopen', self.mock_open) as mock_fdopen:
-            mock_fdopen().read.return_value = simplejson.dumps({
+            mock_fdopen().read.return_value = json.dumps({
                 LISTENER_ID1: {'bin': 1, 'bout': 2},
             })
             msg = health_daemon.build_stats_message()
@@ -353,7 +353,7 @@ class TestHealthDaemon(base.TestCase):
         self.assertEqual(SAMPLE_STATS_MSG, msg)
 
         mock_get_stats.assert_any_call(lb1_stats_socket)
-        mock_fdopen().write.assert_called_once_with(simplejson.dumps({
+        mock_fdopen().write.assert_called_once_with(json.dumps({
             LISTENER_ID1: {
                 'bin': int(FRONTEND_STATS['bin']),
                 'bout': int(FRONTEND_STATS['bout']),
@@ -374,7 +374,7 @@ class TestHealthDaemon(base.TestCase):
                                              mock_is_running):
         health_daemon.COUNTERS = None
         health_daemon.COUNTERS_FILE = None
-        lb1_stats_socket = '/var/lib/octavia/{0}/haproxy.sock'.format(LB_ID1)
+        lb1_stats_socket = f'/var/lib/octavia/{LB_ID1}/haproxy.sock'
         mock_list_files.return_value = {LB_ID1: lb1_stats_socket}
 
         mock_is_running.return_value = False
@@ -450,14 +450,14 @@ class TestHealthDaemon(base.TestCase):
 
         with mock.patch('os.open'), mock.patch.object(
                 os, 'fdopen', self.mock_open) as mock_fdopen:
-            mock_fdopen().read.return_value = simplejson.dumps({
+            mock_fdopen().read.return_value = json.dumps({
                 udp_listener_id1: {
                     'bin': 1, 'bout': 2, "ereq": 0, "stot": 0}
             })
             msg = health_daemon.build_stats_message()
 
         self.assertEqual(expected, msg)
-        mock_fdopen().write.assert_called_once_with(simplejson.dumps({
+        mock_fdopen().write.assert_called_once_with(json.dumps({
             udp_listener_id1: {'bin': 5, 'bout': 10, 'ereq': 0, 'stot': 5},
             udp_listener_id3: {'bin': 0, 'bout': 0, 'ereq': 0, 'stot': 0},
         }))
@@ -472,7 +472,7 @@ class TestHealthDaemon(base.TestCase):
                              mock_get_stats, mock_is_running):
         health_daemon.COUNTERS = None
         health_daemon.COUNTERS_FILE = None
-        lb1_stats_socket = '/var/lib/octavia/{0}/haproxy.sock'.format(LB_ID1)
+        lb1_stats_socket = f'/var/lib/octavia/{LB_ID1}/haproxy.sock'
         mock_list_files.return_value = {LB_ID1: lb1_stats_socket}
 
         mock_is_running.return_value = True
@@ -480,7 +480,7 @@ class TestHealthDaemon(base.TestCase):
 
         with mock.patch('os.open'), mock.patch.object(
                 os, 'fdopen', self.mock_open) as mock_fdopen:
-            mock_fdopen().read.return_value = simplejson.dumps({
+            mock_fdopen().read.return_value = json.dumps({
                 LISTENER_ID1: {'bin': 15, 'bout': 20},
             })
             msg = health_daemon.build_stats_message()
@@ -488,7 +488,7 @@ class TestHealthDaemon(base.TestCase):
         self.assertEqual(SAMPLE_MSG_HAPROXY_RESTART, msg)
 
         mock_get_stats.assert_any_call(lb1_stats_socket)
-        mock_fdopen().write.assert_called_once_with(simplejson.dumps({
+        mock_fdopen().write.assert_called_once_with(json.dumps({
             LISTENER_ID1: {
                 'bin': int(FRONTEND_STATS['bin']),
                 'bout': int(FRONTEND_STATS['bout']),
