@@ -22,7 +22,7 @@ import octavia.tests.unit.base as base
 class TestNetworkNamespace(base.TestCase):
 
     def setUp(self):
-        super(TestNetworkNamespace, self).setUp()
+        super().setUp()
 
     @mock.patch('ctypes.get_errno')
     @mock.patch('ctypes.CDLL')
@@ -50,9 +50,8 @@ class TestNetworkNamespace(base.TestCase):
         mock_cdll_obj = mock.MagicMock()
         mock_cdll.return_value = mock_cdll_obj
         mock_getpid.return_value = FAKE_PID
-        expected_current_netns = '/proc/{pid}/ns/net'.format(pid=FAKE_PID)
-        expected_target_netns = '/var/run/netns/{netns}'.format(
-            netns=FAKE_NETNS)
+        expected_current_netns = f'/proc/{FAKE_PID}/ns/net'
+        expected_target_netns = f'/var/run/netns/{FAKE_NETNS}'
 
         netns = network_namespace.NetworkNamespace(FAKE_NETNS)
 
@@ -72,9 +71,8 @@ class TestNetworkNamespace(base.TestCase):
         mock_getpid.return_value = FAKE_PID
         mock_cdll_obj = mock.MagicMock()
         mock_cdll.return_value = mock_cdll_obj
-        expected_current_netns = '/proc/{pid}/ns/net'.format(pid=FAKE_PID)
-        expected_target_netns = '/var/run/netns/{netns}'.format(
-            netns=FAKE_NETNS)
+        expected_current_netns = f'/proc/{FAKE_PID}/ns/net'
+        expected_target_netns = f'/var/run/netns/{FAKE_NETNS}'
 
         netns = network_namespace.NetworkNamespace(FAKE_NETNS)
 
