@@ -74,6 +74,19 @@ class TestAmphoraDriver(base.TestRpc):
                           self.sample_data.provider_vip_dict,
                           [self.sample_data.provider_additional_vip_dict])
 
+    @mock.patch('octavia.common.utils.get_network_driver')
+    def test_create_vip_port_conflict(self, mock_get_net_driver):
+        mock_net_driver = mock.MagicMock()
+        mock_get_net_driver.return_value = mock_net_driver
+        mock_net_driver.allocate_vip.side_effect = (
+            network_base.VIPInUseException())
+
+        self.assertRaises(exceptions.Conflict,
+                          self.amp_driver.create_vip_port,
+                          self.sample_data.lb_id, self.sample_data.project_id,
+                          self.sample_data.provider_vip_dict,
+                          [self.sample_data.provider_additional_vip_dict])
+
     # Load Balancer
     @mock.patch('oslo_messaging.RPCClient.cast')
     def test_loadbalancer_create(self, mock_cast):
@@ -853,6 +866,16 @@ class TestAmphoraDriver(base.TestRpc):
             m_driver.validate_availability_zone.return_value = None
             ref_dict = {consts.COMPUTE_ZONE: 'my_compute_zone'}
             self.amp_driver.validate_availability_zone(ref_dict)
+            m_driver.validate_availability_zone.assert_called_once_with(
+                'my_compute_zone')
+
+        # Test volume zone
+        with mock.patch('stevedore.driver.DriverManager.driver') as m_driver:
+            m_driver.validate_availability_zone.return_value = None
+            ref_dict = {consts.VOLUME_ZONE: 'my_volume_zone'}
+            self.amp_driver.validate_availability_zone(ref_dict)
+            m_driver.validate_availability_zone.assert_called_once_with(
+                'my_volume_zone')
 
         with mock.patch('octavia.common.utils.get_network_driver') as m_driver:
             # Test vip networks
@@ -878,7 +901,7 @@ class TestAmphoraDriver(base.TestRpc):
                               self.amp_driver.validate_availability_zone,
                               'bogus')
 
-    @mock.patch('cryptography.fernet.Fernet')
+    @mock.patch('cryptography.fernet.MultiFernet')
     def test_encrypt_listener_dict(self, mock_fernet):
         mock_fern = mock.MagicMock()
         mock_fernet.return_value = mock_fern
