@@ -16,6 +16,7 @@ from unittest import mock
 
 from octavia_lib.api.drivers import data_models as driver_dm
 from octavia_lib.api.drivers import exceptions as lib_exceptions
+from oslo_utils import uuidutils
 
 from octavia.api.drivers import utils
 from octavia.common import constants
@@ -38,6 +39,12 @@ class TestUtils(base.TestCase):
                             "arg1", foo="arg2")
         mock_driver_method.assert_called_with("arg1", foo="arg2")
 
+        # Test driver raising VIPAddressConflict
+        mock_driver_method.side_effect = lib_exceptions.Conflict
+        self.assertRaises(exceptions.VIPAddressConflict,
+                          utils.call_provider, "provider_name",
+                          mock_driver_method)
+
         # Test driver raising DriverError
         mock_driver_method.side_effect = lib_exceptions.DriverError
         self.assertRaises(exceptions.ProviderDriverError,
@@ -109,6 +116,7 @@ class TestUtils(base.TestCase):
                                       listener_certs, listener_certs,
                                       listener_certs]
         mock_get_flavor.return_value = {'shaved_ice': 'cherry'}
+        sg_id = uuidutils.generate_uuid()
         test_lb_dict = {'name': 'lb1',
                         'project_id': self.sample_data.project_id,
                         'vip_subnet_id': self.sample_data.subnet_id,
@@ -116,6 +124,7 @@ class TestUtils(base.TestCase):
                         'vip_address': self.sample_data.ip_address,
                         'vip_network_id': self.sample_data.network_id,
                         'vip_qos_policy_id': self.sample_data.qos_policy_id,
+                        'vip_sg_ids': [sg_id],
                         'id': self.sample_data.lb_id,
                         'listeners': [],
                         'pools': [],
@@ -136,6 +145,7 @@ class TestUtils(base.TestCase):
             'vip_port_id': self.sample_data.port_id,
             'vip_qos_policy_id': self.sample_data.qos_policy_id,
             'vip_network_id': self.sample_data.network_id,
+            'vip_sg_ids': [sg_id],
             'pools': self.sample_data.provider_pools,
             'flavor': {'shaved_ice': 'cherry'},
             'name': 'lb1'}
@@ -143,7 +153,8 @@ class TestUtils(base.TestCase):
                               network_id=self.sample_data.network_id,
                               port_id=self.sample_data.port_id,
                               subnet_id=self.sample_data.subnet_id,
-                              qos_policy_id=self.sample_data.qos_policy_id)
+                              qos_policy_id=self.sample_data.qos_policy_id,
+                              sg_ids=[sg_id])
 
         provider_lb_dict = utils.lb_dict_to_provider_dict(
             test_lb_dict, vip=vip, db_pools=self.sample_data.test_db_pools,
@@ -450,7 +461,44 @@ class TestUtils(base.TestCase):
             {'ip_address': '192.0.2.44'})
         self.assertEqual({'vip_address': '192.0.2.44'}, new_vip_dict)
 
+    def test_additional_vip_dict_to_provider_dict(self):
+        new_additional_vip_dict = (
+            utils.additional_vip_dict_to_provider_dict(
+                self.sample_data.test_additional_vip_dict))
+        self.assertEqual(self.sample_data.provider_additional_vip_dict,
+                         new_additional_vip_dict)
+
+        vip_dict = {
+            constants.IP_ADDRESS: mock.Mock()}
+        new_additional_vip_dict = (
+            utils.additional_vip_dict_to_provider_dict(vip_dict))
+        expected_dict = vip_dict
+        self.assertEqual(expected_dict, new_additional_vip_dict)
+
     def test_provider_vip_dict_to_vip_obj(self):
         new_provider_vip = utils.provider_vip_dict_to_vip_obj(
             self.sample_data.provider_vip_dict)
         self.assertEqual(self.sample_data.db_vip, new_provider_vip)
+
+    def test_provider_additional_vip_to_vip_obj(self):
+        new_additional_vip = (
+            utils.provider_additional_vip_dict_to_additional_vip_obj(
+                self.sample_data.provider_additional_vip_dict))
+        self.assertEqual(self.sample_data.db_additional_vip,
+                         new_additional_vip)
+
+        vip_dict = {constants.IP_ADDRESS: mock.Mock()}
+        new_additional_vip = (
+            utils.provider_additional_vip_dict_to_additional_vip_obj(
+                vip_dict))
+        expected_obj = data_models.AdditionalVip(
+            ip_address=vip_dict[constants.IP_ADDRESS])
+        self.assertEqual(expected_obj, new_additional_vip)
+
+        vip_dict = {constants.SUBNET_ID: mock.Mock()}
+        new_additional_vip = (
+            utils.provider_additional_vip_dict_to_additional_vip_obj(
+                vip_dict))
+        expected_obj = data_models.AdditionalVip(
+            subnet_id=vip_dict[constants.SUBNET_ID])
+        self.assertEqual(expected_obj, new_additional_vip)
