@@ -12,7 +12,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import mock
+from unittest import mock
 
 from octavia.cmd import haproxy_vrrp_check
 from octavia.tests.unit import base
@@ -21,7 +21,7 @@ from octavia.tests.unit import base
 class TestHAproxyVRRPCheckCMD(base.TestCase):
 
     def setUp(self):
-        super(TestHAproxyVRRPCheckCMD, self).setUp()
+        super().setUp()
 
     @mock.patch('socket.socket')
     def test_health_check(self, mock_socket):
@@ -31,9 +31,9 @@ class TestHAproxyVRRPCheckCMD(base.TestCase):
         recv_mock.side_effect = [b'1', Exception('BREAK')]
         socket_mock.recv = recv_mock
 
-        self.assertRaisesRegexp(Exception, 'BREAK',
-                                haproxy_vrrp_check.health_check,
-                                '10.0.0.1')
+        self.assertRaisesRegex(Exception, 'BREAK',
+                               haproxy_vrrp_check.health_check,
+                               '10.0.0.1')
 
     @mock.patch('octavia.cmd.haproxy_vrrp_check.health_check')
     @mock.patch('sys.argv')
