@@ -43,15 +43,13 @@ class TestHealthManager(base.TestCase):
         super().setUp()
 
     @mock.patch('octavia.db.api.wait_for_connection')
-    @mock.patch('octavia.controller.worker.v1.controller_worker.'
-                'ControllerWorker.failover_amphora')
     @mock.patch('octavia.controller.worker.v2.controller_worker.'
                 'ControllerWorker.failover_amphora')
     @mock.patch('octavia.db.repositories.AmphoraHealthRepository.'
                 'get_stale_amphora')
     @mock.patch('octavia.db.api.get_session')
     def test_health_check_stale_amphora(self, session_mock, get_stale_amp_mock,
-                                        failover_mockv2, failover_mock,
+                                        failover_mock,
                                         db_wait_mock):
         conf = oslo_fixture.Config(cfg.CONF)
         conf.config(group="health_manager", heartbeat_timeout=5)
@@ -87,15 +85,13 @@ class TestHealthManager(base.TestCase):
         self.assertRaises(TestException, hm.health_check)
         self.assertEqual(4, mock_session.rollback.call_count)
 
-    @mock.patch('octavia.controller.worker.v1.controller_worker.'
-                'ControllerWorker.failover_amphora')
     @mock.patch('octavia.controller.worker.v2.controller_worker.'
                 'ControllerWorker.failover_amphora')
     @mock.patch('octavia.db.repositories.AmphoraHealthRepository.'
                 'get_stale_amphora', return_value=None)
     @mock.patch('octavia.db.api.get_session')
     def test_health_check_nonstale_amphora(self, session_mock,
-                                           get_stale_amp_mock, failover_mockv2,
+                                           get_stale_amp_mock,
                                            failover_mock):
         get_stale_amp_mock.side_effect = [None, TestException('test')]
 
@@ -103,42 +99,32 @@ class TestHealthManager(base.TestCase):
         hm = healthmanager.HealthManager(exit_event)
 
         hm.health_check()
-        session_mock.assert_called_once_with(autocommit=False)
-        if CONF.api_settings.default_provider_driver == 'amphorav2':
-            self.assertFalse(failover_mockv2.called)
-        else:
-            self.assertFalse(failover_mock.called)
+        session_mock.assert_called_once_with()
+        self.assertFalse(failover_mock.called)
 
-    @mock.patch('octavia.controller.worker.v1.controller_worker.'
-                'ControllerWorker.failover_amphora')
     @mock.patch('octavia.controller.worker.v2.controller_worker.'
                 'ControllerWorker.failover_amphora')
     @mock.patch('octavia.db.repositories.AmphoraHealthRepository.'
                 'get_stale_amphora', return_value=None)
     @mock.patch('octavia.db.api.get_session')
     def test_health_check_exit(self, session_mock, get_stale_amp_mock,
-                               failover_mockv2, failover_mock):
+                               failover_mock):
         get_stale_amp_mock.return_value = None
 
         exit_event = threading.Event()
         hm = healthmanager.HealthManager(exit_event)
         hm.health_check()
 
-        session_mock.assert_called_once_with(autocommit=False)
-        if CONF.api_settings.default_provider_driver == 'amphorav2':
-            self.assertFalse(failover_mockv2.called)
-        else:
-            self.assertFalse(failover_mock.called)
+        session_mock.assert_called_once_with()
+        self.assertFalse(failover_mock.called)
 
-    @mock.patch('octavia.controller.worker.v1.controller_worker.'
-                'ControllerWorker.failover_amphora')
     @mock.patch('octavia.controller.worker.v2.controller_worker.'
                 'ControllerWorker.failover_amphora')
     @mock.patch('octavia.db.repositories.AmphoraHealthRepository.'
                 'get_stale_amphora', return_value=None)
     @mock.patch('octavia.db.api.get_session')
     def test_health_check_db_error(self, session_mock, get_stale_amp_mock,
-                                   failover_mockv2, failover_mock):
+                                   failover_mock):
         get_stale_amp_mock.return_value = None
 
         mock_session = mock.MagicMock()
