@@ -12,7 +12,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import mock
+from unittest import mock
 
 import octavia.tests.unit.base as base
 from octavia import version
@@ -21,7 +21,7 @@ from octavia import version
 class TestVersion(base.TestCase):
 
     def setUp(self):
-        super(TestVersion, self).setUp()
+        super().setUp()
 
     def test_vendor_str(self):
         self.assertEqual("OpenStack Foundation", version.vendor_string())
