@@ -15,13 +15,14 @@
 import abc
 
 
-class VolumeBase(object, metaclass=abc.ABCMeta):
+class VolumeBase(metaclass=abc.ABCMeta):
 
     @abc.abstractmethod
-    def create_volume_from_image(self, image_id):
+    def create_volume_from_image(self, image_id, availability_zone=None):
         """Create volume for instance
 
         :param image_id: ID of amphora image
+        :param availability_zone: Availability zone data dict
 
         :return volume id
         """
@@ -41,3 +42,13 @@ class VolumeBase(object, metaclass=abc.ABCMeta):
 
         :return image id
         """
+
+    @abc.abstractmethod
+    def validate_availability_zone(self, availability_zone):
+        """Validates that a volume availability zone exists.
+
+        :param availability_zone: Name of the availability zone to lookup.
+        :returns: None
+        :raises: NotFound
+        :raises: NotImplementedError
+        """
